/**
 * @filename:PaymentBasic 2024-10-24
 * @project KJT v1.1.0 Copyright(c) 2024 wanglang Co. Ltd. All right reserved.
 */
package com.trade.admin.business.payment.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.trade.common.core.domain.BizBaseEntity;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springframework.format.annotation.DateTimeFormat;
import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * @Description:支付基础表实体类
 * @version: v1.1.0
 * @author: wanglang
 */
@Data
@EqualsAndHashCode(callSuper = false)
// @Accessors(chain = true)
public class PaymentBasic extends BizBaseEntity {

    private static final long serialVersionUID = 1729769777049L;
    @ApiModelProperty(name = "customerUserId", value = "客户id")
    private Long customerUserId;
    @ApiModelProperty(name = "separateAccountsInfoId", value = "分账信息主表id")
    private Long separateAccountsInfoId;
    @ApiModelProperty(name = "salesContractNo", value = "销售合同编号")
    private String salesContractNo;
    @ApiModelProperty(name = "contractName", value = "销售合同名称")
    private String contractName;
    @ApiModelProperty(name = "importerCertNo", value = "进口商统一社会信用代码/注册号")
    private String importerCertNo;
    @ApiModelProperty(name = "importerEnterpriseName", value = "进口商企业名称")
    private String importerEnterpriseName;
    @ApiModelProperty(name = "agencyCertNo", value = "代理公司统一社会信用代码/注册号")
    private String agencyCertNo;
    @ApiModelProperty(name = "agencyEnterpriseName", value = "代理公司企业名称")
    private String agencyEnterpriseName;
    @ApiModelProperty(name = "financierIdentifier", value = "资金方标识")
    private String financierIdentifier;
    @ApiModelProperty(name = "paymentType", value = "款项类型1出口退税款2贷款差额3贷款结汇差额")
    private String paymentType;
    @ApiModelProperty(name = "status", value = "支付状态1待审批2退回3出账确认中4出账已确认")
    private String status;
    @ApiModelProperty(name = "transactionNumber", value = "交易编号")
    private String transactionNumber;
    @ApiModelProperty(name = "businessNumber", value = "业务编号")
    private String businessNumber;
    @ApiModelProperty(name = "paymentAmount", value = "付款金额")
    private BigDecimal paymentAmount;
    @ApiModelProperty(name = "paymentCurrency", value = "付款金额币种代码")
    private String paymentCurrency;
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiModelProperty(name = "applyDate", value = "申请日期")
    private LocalDateTime applyDate;
    @ApiModelProperty(name = "settlementAmount", value = "结汇人民币金额")
    private BigDecimal settlementAmount;
    @ApiModelProperty(name = "actualRetainedAmount", value = "实际留存人民币金额")
    private BigDecimal actualRetainedAmount;
    @ApiModelProperty(name = "currencyCode", value = "结汇人民币金额币种")
    private String settlementCurrency;
    @ApiModelProperty(name = "currencyCode", value = "币种")
    private String actualRetainedCurrency;
}
