-- ----------------------------
-- 1、部门表
-- ----------------------------
drop table if exists sys_dept;
create table sys_dept
(
    id      bigint(20) not null auto_increment comment '部门id',
    parent_id    bigint(20) default 0 comment '父部门id',
    ancestors    varchar(50) default '' comment '祖级列表',
    dept_name    varchar(30) default '' comment '部门名称',
    order_num    int(4) default 0 comment '显示顺序',
    leader       varchar(20) default null comment '负责人',
    phone        varchar(11) default null comment '联系电话',
    email        varchar(50) default null comment '邮箱',
    status       char(1)     default '0' comment '部门状态（0正常 1停用）',
    del_flag     char(1)     default '0' comment '删除标志（0代表存在 2代表删除）',
    create_by    varchar(64) default '' comment '创建者',
    update_by    varchar(64) default '' comment '更新者',
    gmt_create   TIMESTAMP   DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP   DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '部门表';

insert into sys_dept values(100,  0,   '0',   '长安银科资产管理有限公司',   0, 'admin', '15888888888', '', '0', '0', 'admin', '', sysdate(), sysdate());

-- ----------------------------
-- 2、用户信息表
-- ----------------------------
drop table if exists sys_user;
create table sys_user
(
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '用户ID',
    `dept_id` bigint(20) DEFAULT NULL COMMENT '部门ID',
    `user_name` varchar(30) NOT NULL COMMENT '用户账号',
    `nick_name` varchar(30) NOT NULL COMMENT '用户昵称',
    `user_type` varchar(2) DEFAULT '00' COMMENT '用户类型（00系统用户）',
    `email` varchar(50) DEFAULT '' COMMENT '用户邮箱',
    `phonenumber` varchar(11) DEFAULT '' COMMENT '手机号码',
    `sex` char(1) DEFAULT '0' COMMENT '用户性别（0男 1女 2未知）',
    `avatar` varchar(100) DEFAULT '' COMMENT '头像地址',
    `password` varchar(100) DEFAULT '' COMMENT '密码',
    `status` char(1) DEFAULT '0' COMMENT '帐号状态（0正常 1停用）',
    `user_identity` tinyint(4) DEFAULT '0' COMMENT '1-负责人，0-普通职员',
    `del_flag` char(1) DEFAULT '0' COMMENT '删除标志（0代表存在 2代表删除）',
    `login_ip` varchar(128) DEFAULT '' COMMENT '最后登录IP',
    `login_date` datetime DEFAULT NULL COMMENT '最后登录时间',
    `create_by` varchar(64) DEFAULT '' COMMENT '创建者',
    `update_by` varchar(64) DEFAULT '' COMMENT '更新者',
    `remark` varchar(500) DEFAULT NULL COMMENT '备注',
    `built_in_user` tinyint(4) DEFAULT '0' COMMENT '1 内置用户',
    `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`)
)ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '用户信息表';

-- ----------------------------
-- 初始化-用户信息表数据
-- ----------------------------
insert into sys_user values(1,  100, 'admin', '超级管理员', '00', '', '18888888888', '1', '', '$2a$10$7JB720yubVSZvUI0rEqK/.VqGOZTH.ulu33dHOiBE8ByOhJIrdAu2', '0','0', '0', '127.0.0.1', sysdate(), 'admin', '', '管理员',1, sysdate(), sysdate());
-- ----------------------------
-- 3、岗位信息表
-- ----------------------------
drop table if exists sys_post;
create table sys_post
(
    id      bigint(20) not null auto_increment comment '岗位ID',
    post_code    varchar(64) not null comment '岗位编码',
    post_name    varchar(50) not null comment '岗位名称',
    post_sort    int(4) not null comment '显示顺序',
    status       char(1)     not null comment '状态（0正常 1停用）',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '岗位信息表';

-- 初始化-岗位信息表数据
-- ----------------------------
insert into sys_post values(1, 'ceo',  '董事长',    1, '0', 'admin',  '', null, sysdate(), sysdate());
insert into sys_post values(2, 'se',   '项目经理',  2, '0', 'admin', '', null, sysdate(), sysdate());
insert into sys_post values(3, 'hr',   '人力资源',  3, '0', 'admin',  '', null, sysdate(), sysdate());
insert into sys_post values(4, 'user', '普通员工',  4, '0', 'admin', '', null, sysdate(), sysdate());
-- ----------------------------
-- 4、角色信息表
-- ----------------------------
drop table if exists sys_role;
create table sys_role
(
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '角色ID',
    `role_name` varchar(30) NOT NULL COMMENT '角色名称',
    `role_key` varchar(100) NOT NULL COMMENT '角色权限字符串',
    `role_sort` int(4) NOT NULL COMMENT '显示顺序',
    `data_scope` char(1) DEFAULT '1' COMMENT '数据范围（1：全部数据权限 2：自定数据权限 3：本部门数据权限 4：本部门及以下数据权限）',
    `menu_check_strictly` tinyint(1) DEFAULT '1' COMMENT '菜单树选择项是否关联显示',
    `dept_check_strictly` tinyint(1) DEFAULT '1' COMMENT '部门树选择项是否关联显示',
    `status` char(1) NOT NULL COMMENT '角色状态（0正常 1停用）',
    `built_in_role` tinyint(4) DEFAULT '0' COMMENT '内置角色（1：内置角色，0：自定义角色',
    `del_flag` char(1) DEFAULT '0' COMMENT '删除标志（0代表存在 2代表删除）',
    `create_by` varchar(64) DEFAULT '' COMMENT '创建者',
    `update_by` varchar(64) DEFAULT '' COMMENT '更新者',
    `remark` varchar(500) DEFAULT NULL COMMENT '备注',
    `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '角色信息表';

INSERT INTO `sys_role` (`id`,`role_name`, `role_key`, `role_sort`, `data_scope`, `menu_check_strictly`, `dept_check_strictly`, `status`, `built_in_role`, `del_flag`, `create_by`, `update_by`, `remark`) VALUES (1,'超级管理员', 'admin', 1, '1', 1, 1, '0', 1, '0', 'admin', '', '默认角色，请勿删除！');
INSERT INTO `sys_role` (`id`,`role_name`, `role_key`, `role_sort`, `data_scope`, `menu_check_strictly`, `dept_check_strictly`, `status`, `built_in_role`, `del_flag`, `create_by`, `update_by`, `remark`) VALUES (2,'业务超管', 'businessAdmin', 2, '1', 1, 1, '0', 1, '0', 'admin', '长安银科', '默认角色，请勿删除！');
INSERT INTO `sys_role` (`id`,`role_name`, `role_key`, `role_sort`, `data_scope`, `menu_check_strictly`, `dept_check_strictly`, `status`, `built_in_role`, `del_flag`, `create_by`, `update_by`, `remark`) VALUES (3,'风控经理', 'RC', 3, '1', 1, 1, '0', 1, '0', 'admin', '长安银科', '默认角色，请勿删除！');
INSERT INTO `sys_role` (`id`,`role_name`, `role_key`, `role_sort`, `data_scope`, `menu_check_strictly`, `dept_check_strictly`, `status`, `built_in_role`, `del_flag`, `create_by`, `update_by`, `remark`) VALUES (4,'业务经理', 'BD', 4, '1', 1, 1, '0', 1, '0', 'admin', '长安银科', '默认角色，请勿删除！');
INSERT INTO `sys_role` (`id`,`role_name`, `role_key`, `role_sort`, `data_scope`, `menu_check_strictly`, `dept_check_strictly`, `status`, `built_in_role`, `del_flag`, `create_by`, `update_by`, `remark`) VALUES (5,'出口退税办理人', 'EXPORT_TAX_REFUNDER', 5, '1', 1, 1, '0', 1, '0', 'admin', '', '默认角色，请勿删除！');

-- ----------------------------
-- 5、菜单权限表
-- ----------------------------
drop table if exists sys_menu;
create table sys_menu
(
    id      bigint(20) not null auto_increment comment '菜单ID',
    menu_name    varchar(50) not null comment '菜单名称',
    parent_id    bigint(20) default 0 comment '父菜单ID',
    order_num    int(4) default 0 comment '显示顺序',
    path         varchar(200) default '' comment '路由地址',
    component    varchar(255) default null comment '组件路径',
    query        varchar(255) default null comment '路由参数',
    is_frame     int(1) default 1 comment '是否为外链（0是 1否）',
    is_cache     int(1) default 0 comment '是否缓存（0缓存 1不缓存）',
    menu_type    char(1)      default '' comment '菜单类型（M目录 C菜单 F按钮）',
    visible      char(1)      default 0 comment '菜单状态（0显示 1隐藏）',
    status       char(1)      default 0 comment '菜单状态（0正常 1停用）',
    perms        varchar(100) default null comment '权限标识',
    icon         varchar(100) default '#' comment '菜单图标',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default '' comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '菜单权限表';

-- ----------------------------
-- 初始化-菜单信息表数据
-- ----------------------------
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1, '系统管理', 0, 8, 'system', NULL, '', 1, 0, 'M', '0', '0', '', 'system', 'admin', 'admin', '系统管理目录', '2024-05-25 16:58:18', '2024-09-21 11:21:10');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (2, '系统监控', 0, 9, 'monitor', NULL, '', 1, 0, 'M', '0', '0', '', 'monitor', 'admin', 'admin', '系统监控目录', '2024-05-25 16:58:18', '2024-09-21 11:21:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (100, '用户管理', 1, 1, 'user', 'system/user/index', '', 1, 0, 'C', '0', '0', 'system:user:list', 'user', 'admin', 'admin', '用户管理菜单', '2024-05-25 16:58:18', '2024-09-14 16:42:46');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (101, '角色管理', 1, 2, 'role', 'system/role/index', '', 1, 0, 'C', '0', '0', 'system:role:list', 'peoples', 'admin', 'admin', '角色管理菜单', '2024-05-25 16:58:18', '2024-09-14 16:43:00');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (102, '菜单管理', 1, 3, 'menu', 'system/menu/index', '', 1, 0, 'C', '0', '0', 'system:menu:list', 'tree-table', 'admin', 'admin', '菜单管理菜单', '2024-05-25 16:58:18', '2024-09-14 16:43:08');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (103, '部门管理', 1, 4, 'dept', 'system/dept/index', '', 1, 0, 'C', '0', '0', 'system:dept:list', 'tree', 'admin', 'admin', '部门管理菜单', '2024-05-25 16:58:18', '2024-09-14 16:43:18');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (104, '岗位管理', 1, 5, 'post', 'system/post/index', '', 1, 0, 'C', '0', '0', 'system:post:list', 'post', 'admin', 'admin', '岗位管理菜单', '2024-05-25 16:58:18', '2024-09-14 16:43:25');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (105, '字典管理', 1, 6, 'dict', 'system/dict/index', '', 1, 0, 'C', '0', '0', 'system:dict:list', 'dict', 'admin', 'admin', '字典管理菜单', '2024-05-25 16:58:18', '2024-09-14 16:43:31');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (106, '参数设置', 1, 7, 'config', 'system/config/index', '', 1, 0, 'C', '0', '0', 'system:config:list', 'edit', 'admin', 'admin', '参数设置菜单', '2024-05-25 16:58:18', '2024-09-14 16:43:38');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (107, '通知公告', 1, 8, 'notice', 'system/notice/index', '', 1, 0, 'C', '0', '0', 'system:notice:list', 'message', 'admin', 'admin', '通知公告菜单', '2024-05-25 16:58:19', '2024-09-14 16:43:44');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (108, '日志管理', 1, 9, 'log', '', '', 1, 0, 'M', '0', '0', '', 'log', 'admin', 'admin', '日志管理菜单', '2024-05-25 16:58:19', '2024-09-14 16:43:52');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (109, '在线用户', 2, 1, 'online', 'monitor/online/index', '', 1, 0, 'C', '0', '0', 'monitor:online:list', 'online', 'admin', 'admin', '在线用户菜单', '2024-05-25 16:58:19', '2024-09-14 16:44:02');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (110, '服务监控', 2, 4, 'server', 'monitor/server/index', '', 1, 0, 'C', '0', '0', 'monitor:server:list', 'server', 'admin', 'admin', '服务监控菜单', '2024-05-25 16:58:19', '2024-09-14 16:44:08');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (500, '操作日志', 108, 1, 'operlog', 'monitor/operlog/index', '', 1, 0, 'C', '0', '0', 'monitor:operlog:list', 'form', 'admin', '', '操作日志菜单', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (501, '登录日志', 108, 2, 'logininfor', 'monitor/logininfor/index', '', 1, 0, 'C', '0', '0', 'monitor:logininfor:list', 'logininfor', 'admin', '', '登录日志菜单', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1000, '用户查询', 100, 1, '', '', '', 1, 0, 'F', '0', '0', 'system:user:query', '#', 'admin', '', '', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1001, '用户新增', 100, 2, '', '', '', 1, 0, 'F', '0', '0', 'system:user:add', '#', 'admin', '', '', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1002, '用户修改', 100, 3, '', '', '', 1, 0, 'F', '0', '0', 'system:user:edit', '#', 'admin', '', '', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1003, '用户删除', 100, 4, '', '', '', 1, 0, 'F', '0', '0', 'system:user:remove', '#', 'admin', '', '', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1004, '用户导出', 100, 5, '', '', '', 1, 0, 'F', '0', '0', 'system:user:export', '#', 'admin', '', '', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1005, '用户导入', 100, 6, '', '', '', 1, 0, 'F', '0', '0', 'system:user:import', '#', 'admin', '', '', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1006, '重置密码', 100, 7, '', '', '', 1, 0, 'F', '0', '0', 'system:user:resetPwd', '#', 'admin', '', '', '2024-05-25 16:58:19', '2024-05-25 16:58:19');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1007, '角色查询', 101, 1, '', '', '', 1, 0, 'F', '0', '0', 'system:role:query', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1008, '角色新增', 101, 2, '', '', '', 1, 0, 'F', '0', '0', 'system:role:add', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1009, '角色修改', 101, 3, '', '', '', 1, 0, 'F', '0', '0', 'system:role:edit', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1010, '角色删除', 101, 4, '', '', '', 1, 0, 'F', '0', '0', 'system:role:remove', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1011, '角色导出', 101, 5, '', '', '', 1, 0, 'F', '0', '0', 'system:role:export', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1012, '菜单查询', 102, 1, '', '', '', 1, 0, 'F', '0', '0', 'system:menu:query', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1013, '菜单新增', 102, 2, '', '', '', 1, 0, 'F', '0', '0', 'system:menu:add', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1014, '菜单修改', 102, 3, '', '', '', 1, 0, 'F', '0', '0', 'system:menu:edit', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1015, '菜单删除', 102, 4, '', '', '', 1, 0, 'F', '0', '0', 'system:menu:remove', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1016, '部门查询', 103, 1, '', '', '', 1, 0, 'F', '0', '0', 'system:dept:query', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1017, '部门新增', 103, 2, '', '', '', 1, 0, 'F', '0', '0', 'system:dept:add', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1018, '部门修改', 103, 3, '', '', '', 1, 0, 'F', '0', '0', 'system:dept:edit', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1019, '部门删除', 103, 4, '', '', '', 1, 0, 'F', '0', '0', 'system:dept:remove', '#', 'admin', '', '', '2024-05-25 16:58:20', '2024-05-25 16:58:20');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1020, '岗位查询', 104, 1, '', '', '', 1, 0, 'F', '0', '0', 'system:post:query', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1021, '岗位新增', 104, 2, '', '', '', 1, 0, 'F', '0', '0', 'system:post:add', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1022, '岗位修改', 104, 3, '', '', '', 1, 0, 'F', '0', '0', 'system:post:edit', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1023, '岗位删除', 104, 4, '', '', '', 1, 0, 'F', '0', '0', 'system:post:remove', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1024, '岗位导出', 104, 5, '', '', '', 1, 0, 'F', '0', '0', 'system:post:export', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1025, '字典查询', 105, 1, '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:query', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1026, '字典新增', 105, 2, '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:add', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1027, '字典修改', 105, 3, '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:edit', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1028, '字典删除', 105, 4, '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:remove', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1029, '字典导出', 105, 5, '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:export', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1030, '参数查询', 106, 1, '#', '', '', 1, 0, 'F', '0', '0', 'system:config:query', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1031, '参数新增', 106, 2, '#', '', '', 1, 0, 'F', '0', '0', 'system:config:add', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1032, '参数修改', 106, 3, '#', '', '', 1, 0, 'F', '0', '0', 'system:config:edit', '#', 'admin', '', '', '2024-05-25 16:58:21', '2024-05-25 16:58:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1033, '参数删除', 106, 4, '#', '', '', 1, 0, 'F', '0', '0', 'system:config:remove', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1034, '参数导出', 106, 5, '#', '', '', 1, 0, 'F', '0', '0', 'system:config:export', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1035, '公告查询', 107, 1, '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:query', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1036, '公告新增', 107, 2, '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:add', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1037, '公告修改', 107, 3, '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:edit', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1038, '公告删除', 107, 4, '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:remove', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1039, '操作查询', 500, 1, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:query', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1040, '操作删除', 500, 2, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:remove', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1041, '日志导出', 500, 3, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:export', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1042, '登录查询', 501, 1, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:query', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1043, '登录删除', 501, 2, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:remove', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1044, '日志导出', 501, 3, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:export', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1045, '账户解锁', 501, 4, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:unlock', '#', 'admin', '', '', '2024-05-25 16:58:22', '2024-05-25 16:58:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1046, '在线查询', 109, 1, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:query', '#', 'admin', '', '', '2024-05-25 16:58:23', '2024-05-25 16:58:23');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1047, '批量强退', 109, 2, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:batchLogout', '#', 'admin', '', '', '2024-05-25 16:58:23', '2024-05-25 16:58:23');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1048, '单条强退', 109, 3, '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:forceLogout', '#', 'admin', '', '', '2024-05-25 16:58:23', '2024-05-25 16:58:23');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1049, '企业管理', 0, 0, 'enterprise', NULL, NULL, 1, 0, 'M', '0', '0', '', 'excel', '', 'admin', '', '2024-09-20 11:06:33', '2024-09-21 12:00:35');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1050, '客户管理', 1049, 0, 'customer', 'enterprise/customer/index', NULL, 1, 0, 'C', '0', '0', 'customer:enterprise:list', 'peoples', '', 'admin', '', '2024-09-20 11:07:42', '2024-09-29 17:43:36');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1051, '客户详情', 1050, 1, '', '', NULL, 1, 0, 'F', '0', '0', 'customer:enterprise:detail', '#', '', '', '', '2024-09-20 11:10:01', '2024-09-20 11:17:04');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1052, '客户认领', 1050, 2, '', NULL, NULL, 1, 0, 'F', '0', '0', 'customer:enterprise:claim', '#', '', '', '', '2024-09-20 11:11:44', '2024-09-20 11:17:06');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1053, '分配风控、业务经理', 1050, 3, '', NULL, NULL, 1, 0, 'F', '0', '0', 'customer:enterprise:assignAdjustment', '#', '', '', '', '2024-09-20 11:15:02', '2024-09-20 11:17:27');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1054, '移交风控、业务经理', 1050, 4, '', NULL, NULL, 1, 0, 'F', '0', '0', 'customer:enterprise:transfer', '#', '', '', '', '2024-09-20 11:15:06', '2024-09-20 11:17:28');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1055, '贸易相关企业', 1049, 1, 'tradeRelation', 'enterprise/tradeRelation/index', NULL, 1, 0, 'C', '0', '0', 'enterpiise:rel:list', 'international', '', 'admin', '', '2024-09-20 11:16:55', '2024-09-21 11:55:10');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1056, '进口商', 1055, 0, 'importerEntity', '', NULL, 1, 0, 'F', '1', '0', 'customer:rel:companyImporter:list', '#', '', '长安银科', '', '2024-09-20 11:18:36', '2024-10-10 21:05:02');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1057, '详情', 1056, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'customer:rel:companyImporter:detail', '#', '', '长安银科', '', '2024-09-20 11:19:07', '2024-10-10 21:05:13');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1058, '供应商', 1055, 0, 'vendorEntity', '', NULL, 1, 0, 'F', '1', '0', 'customer:rel:vendor:list', '#', '', '长安银科', '', '2024-09-20 11:19:28', '2024-10-10 21:05:59');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1059, '详情', 1058, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'customer:rel:vendor:detail', '#', '', '长安银科', '', '2024-09-20 11:19:40', '2024-10-10 21:06:09');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1060, '贸易平台管理', 0, 1, 'tradePlatform', 'tradePlatform/index', NULL, 1, 0, 'C', '0', '0', 'tradingPlatform:list', 'redis', '', '长安银科', '', '2024-09-20 11:23:10', '2024-10-10 21:04:12');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1061, '详情', 1060, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'tradingPlatform:detil', '#', '', '', '', '2024-09-20 11:29:46', '2024-09-20 11:30:59');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1062, '新增', 1060, 1, '', NULL, NULL, 1, 0, 'F', '0', '0', 'tradingPlatform:add', '#', '', '', '', '2024-09-20 11:31:06', '2024-09-20 11:31:46');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1063, '编辑', 1060, 2, '', NULL, NULL, 1, 0, 'F', '0', '0', 'tradingPlatform:update', '#', '', '', '', '2024-09-20 11:31:11', '2024-09-20 11:31:49');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1064, '购销合同', 0, 2, 'psContract', 'psContract/index', NULL, 1, 0, 'C', '0', '0', NULL, 'form', '长安银科', '', '', '2024-09-26 17:01:22', '2024-09-26 17:01:22');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1065, '订单与单据', 0, 3, 'order', NULL, NULL, 1, 0, 'M', '0', '0', NULL, 'documentation', '长安银科', '', '', '2024-10-10 10:53:26', '2024-10-10 10:53:26');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1066, '销售订单与单据', 1065, 0, 'order/salesOrder', 'order/salesOrder/index', NULL, 1, 0, 'C', '0', '0', '', 'list', '长安银科', '长安银科', '', '2024-10-10 10:56:27', '2024-10-10 21:19:43');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1067, '采购订单与单据', 1065, 1, 'order/purchaseOrder', 'order/purchaseOrder/index', NULL, 1, 0, 'C', '0', '0', '', 'list', '长安银科', '长安银科', '', '2024-10-10 10:57:46', '2024-10-10 21:19:48');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1068, '销售合同', 1064, 0, 'salesContracts/index', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesContract:pages', '#', '长安银科', '长安银科', '', '2024-10-10 21:08:21', '2024-10-10 21:13:05');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1069, '详情', 1068, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesContract:query', '#', '长安银科', '长安银科', '', '2024-10-10 21:10:35', '2024-10-10 21:13:15');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1070, '采购合同', 1064, 1, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:purchaseContract:pages', '#', '长安银科', '', '', '2024-10-10 21:12:21', '2024-10-10 21:12:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1071, '详情', 1070, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:purchaseContract:query', '#', '长安银科', '', '', '2024-10-10 21:12:48', '2024-10-10 21:12:48');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1072, '销售订单', 1066, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesOrder:list', '#', '长安银科', '长安银科', '', '2024-10-10 21:21:40', '2024-10-10 21:21:53');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1073, '详情', 1072, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesOrder:detail', '#', '长安银科', '', '', '2024-10-10 21:22:18', '2024-10-10 21:22:18');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1074, '销售发票', 1066, 1, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesInvoice:list', '#', '长安银科', '', '', '2024-10-10 21:23:33', '2024-10-10 21:23:33');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1075, '详情', 1074, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesInvoice:detail', '#', '长安银科', '', '', '2024-10-10 21:23:57', '2024-10-10 21:23:57');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1076, '物流运输', 1066, 2, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesLogistics:list', '#', '长安银科', '', '', '2024-10-10 21:25:08', '2024-10-10 21:25:08');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1077, '详情', 1076, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesLogistics:detail', '#', '长安银科', '', '', '2024-10-10 21:25:26', '2024-10-10 21:25:26');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1078, '报关单', 1066, 3, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesBgd:list', '#', '长安银科', '', '', '2024-10-10 21:26:14', '2024-10-10 21:26:14');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1079, '详情', 1078, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:salesBgd:detail', '#', '长安银科', '', '', '2024-10-10 21:26:32', '2024-10-10 21:26:32');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1080, '采购订单', 1067, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:purchaseOrder:pages', '#', '长安银科', '', '', '2024-10-10 21:27:46', '2024-10-10 21:27:46');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1081, '详情', 1080, 0, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:purchaseOrder:details', '#', '长安银科', '', '', '2024-10-10 21:28:26', '2024-10-10 21:28:26');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1082, '下载发票', 1080, 1, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:purchaseOrder:pullInvoice', '#', '长安银科', '', '', '2024-10-10 21:32:06', '2024-10-10 21:32:06');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1083, '采购发票', 1067, 1, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:purchaseOrder:invoicePage', '#', '长安银科', '长安银科', '', '2024-10-10 21:33:04', '2024-10-10 21:34:42');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1084, '详情', 1083, 1, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:purchaseOrder:invoiceDetail', '#', '长安银科', '', '', '2024-10-10 21:33:21', '2024-10-10 21:33:21');
INSERT INTO `sys_menu` (`id`, `menu_name`, `parent_id`, `order_num`, `path`, `component`, `query`, `is_frame`, `is_cache`, `menu_type`, `visible`, `status`, `perms`, `icon`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1085, '物流运输', 1067, 2, '', NULL, NULL, 1, 0, 'F', '0', '0', 'trade:purchaseOrder:logisticsPage', '#', '长安银科', '', '', '2024-10-10 21:33:55', '2024-10-10 21:33:55');


-- ----------------------------
-- 6、用户和角色关联表  用户N-1角色
-- ----------------------------
drop table if exists sys_user_role;
create table sys_user_role
(
    user_id bigint(20) not null comment '用户ID',
    role_id bigint(20) not null comment '角色ID',
    primary key (user_id, role_id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '用户和角色关联表';

-- ----------------------------
-- 初始化-用户和角色关联表数据
-- ----------------------------
insert into sys_user_role
values ('1', '1');


-- ----------------------------
-- 7、角色和菜单关联表  角色1-N菜单
-- ----------------------------
drop table if exists sys_role_menu;
create table sys_role_menu
(
    role_id bigint(20) not null comment '角色ID',
    menu_id bigint(20) not null comment '菜单ID',
    primary key (role_id, menu_id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '角色和菜单关联表';

-- ----------------------------
-- 8、角色和部门关联表  角色1-N部门
-- ----------------------------
drop table if exists sys_role_dept;
create table sys_role_dept
(
    role_id bigint(20) not null comment '角色ID',
    dept_id bigint(20) not null comment '部门ID',
    primary key (role_id, dept_id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '角色和部门关联表';


-- ----------------------------
-- 9、用户与岗位关联表  用户1-N岗位
-- ----------------------------
drop table if exists sys_user_post;
create table sys_user_post
(
    user_id bigint(20) not null comment '用户ID',
    post_id bigint(20) not null comment '岗位ID',
    primary key (user_id, post_id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '用户与岗位关联表';

-- ----------------------------
-- 10、操作日志记录
-- ----------------------------
drop table if exists sys_oper_log;
create table sys_oper_log
(
    id        bigint(20) not null auto_increment comment '日志主键',
    title          varchar(50)   default '' comment '模块标题',
    business_type  int(2) default 0 comment '业务类型（0其它 1新增 2修改 3删除）',
    method         varchar(100)  default '' comment '方法名称',
    request_method varchar(10)   default '' comment '请求方式',
    operator_type  int(1) default 0 comment '操作类别（0其它 1后台用户 2手机端用户）',
    oper_name      varchar(50)   default '' comment '操作人员',
    dept_name      varchar(50)   default '' comment '部门名称',
    oper_url       varchar(255)  default '' comment '请求URL',
    oper_ip        varchar(128)  default '' comment '主机地址',
    oper_location  varchar(255)  default '' comment '操作地点',
    oper_param     varchar(2000) default '' comment '请求参数',
    json_result    varchar(2000) default '' comment '返回参数',
    status         int(1) default 0 comment '操作状态（0正常 1异常）',
    error_msg      varchar(2000) default '' comment '错误消息',
    oper_time      datetime comment '操作时间',
    cost_time      bigint(20) default 0 comment '消耗时间',
    gmt_create     TIMESTAMP     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified   TIMESTAMP     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id),
    key            idx_sys_oper_log_bt (business_type),
    key            idx_sys_oper_log_s (status),
    key            idx_sys_oper_log_ot (oper_time)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '操作日志记录';


-- ----------------------------
-- 11、字典类型表
-- ----------------------------
drop table if exists sys_dict_type;
create table sys_dict_type
(
    id      bigint(20) not null auto_increment comment '字典主键',
    dict_name    varchar(100) default '' comment '字典名称',
    dict_type    varchar(100) default '' comment '字典类型',
    status       char(1)      default '0' comment '状态（0正常 1停用）',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id),
    unique (dict_type)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '字典类型表';

INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1, '用户性别', 'sys_user_sex', '0', 'admin', '', '用户性别列表', '2024-05-25 16:58:24', '2024-05-25 16:58:24');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (2, '菜单状态', 'sys_show_hide', '0', 'admin', '', '菜单状态列表', '2024-05-25 16:58:24', '2024-05-25 16:58:24');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (3, '系统开关', 'sys_normal_disable', '0', 'admin', '', '系统开关列表', '2024-05-25 16:58:24', '2024-05-25 16:58:24');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (4, '任务状态', 'sys_job_status', '0', 'admin', '', '任务状态列表', '2024-05-25 16:58:24', '2024-05-25 16:58:24');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (5, '任务分组', 'sys_job_group', '0', 'admin', '', '任务分组列表', '2024-05-25 16:58:24', '2024-05-25 16:58:24');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (6, '系统是否', 'sys_yes_no', '0', 'admin', '', '系统是否列表', '2024-05-25 16:58:24', '2024-05-25 16:58:24');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (7, '通知类型', 'sys_notice_type', '0', 'admin', '', '通知类型列表', '2024-05-25 16:58:24', '2024-05-25 16:58:24');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (8, '通知状态', 'sys_notice_status', '0', 'admin', '', '通知状态列表', '2024-05-25 16:58:24', '2024-05-25 16:58:24');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (9, '操作类型', 'sys_oper_type', '0', 'admin', '', '操作类型列表', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (10, '系统状态', 'sys_common_status', '0', 'admin', '', '登录状态列表', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (11, '企业类型', 'enterprise_type', '0', 'admin', '', '企业类型', '2024-05-27 20:16:28', '2024-05-27 20:16:28');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (12, '贸易类型', 'trade_type', '0', 'admin', '', '贸易类型枚举', '2024-05-27 20:16:43', '2024-05-27 20:16:58');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (13, '关系类型', 'trade_relation_type', '0', 'admin', '', '贸易关系类型', '2024-05-27 20:23:08', '2024-05-27 20:23:08');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (14, '所属国家', 'country_code', '0', 'admin', '', '所属国家编码', '2024-05-27 20:26:37', '2024-05-27 20:26:56');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (15, '业务产品', 'business_product', '0', 'admin', '', '业务类型列表', '2024-05-27 20:39:23', '2024-05-27 20:39:23');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (16, '出口类型', 'export_type', '0', 'admin', '', '出口类型列表', '2024-05-28 17:53:26', '2024-05-28 17:53:26');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (17, '货物来源', 'goods_source', '0', 'admin', '', '货物来源列表', '2024-05-28 17:54:35', '2024-05-28 17:54:35');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (18, '个人证件类型', 'personal_cert_type', '0', 'admin', '', '个人证件类型列表', '2024-05-28 18:53:44', '2024-05-28 18:53:44');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (19, '婚姻状况', 'marriage_status', '0', 'admin', '', '婚姻状况列表', '2024-05-28 19:01:36', '2024-05-28 19:01:36');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (20, '经营品类', 'business_category', '0', 'admin', '', '经营品类', '2024-05-29 14:22:48', '2024-05-29 14:23:02');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (21, '认证状态', 'certification_status', '0', 'admin', '', '认证状态列表', '2024-05-30 11:24:55', '2024-05-30 11:24:55');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (22, '所属区域', 'district_code', '0', 'admin', '', '所属区域', '2024-06-05 14:49:41', '2024-06-05 14:49:57');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (24, '客户推荐码前缀', 'customer_register_prefix', '0', 'admin', '', '客户推荐码前缀列表', '2024-06-06 09:58:19', '2024-06-06 09:58:19');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (25, '保险类型', 'insurance_type', '0', 'admin', '', '保险类型', '2024-06-11 14:54:56', '2024-06-11 14:54:56');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (26, '购销合同付款时点', 'payment_time', '0', 'admin', '', '购销合同付款时点', '2024-09-09 16:06:58', '2024-09-09 16:06:58');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (27, '采购合同状态', 'purchase_contract_status', '0', 'admin', '', '采购合同状态', '2024-09-10 19:09:13', '2024-09-10 19:09:27');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (28, '小图-主管税务机关', 'tax_authority_area', '0', '', '', '小图-主管税务机关', '2024-09-19 21:31:44', '2024-09-19 21:31:44');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (29, '购销合同付款方式', 'payment_way', '0', 'admin', '', '购销合同付款方式', '2024-09-24 16:23:04', '2024-09-24 16:23:04');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (30, '币种', 'currency_code', '0', '长安银科', '', '币种', '2024-09-24 17:37:22', '2024-09-24 17:37:22');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (31, '签署状态', 'sys_sign_status', '0', '长安银科', '长安银科', '合同函件签署状态', '2024-09-26 15:50:16', '2024-09-26 15:50:42');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (32, '贸易术语', 'trade_terms', '0', 'admin', '', '贸易术语', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (33, '发票类型', 'invoice_type', '0', '长安银科', '', NULL, '2024-09-28 16:46:22', '2024-09-28 16:46:22');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (34, '销售合同状态', 'sales_contract_status', '0', 'admin', '长安银科', '合同状态', '2024-09-29 14:41:32', '2024-09-29 14:43:27');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (35, '销售订单状态', 'sales_order_status', '0', '长安银科', '', NULL, '2024-10-10 09:23:01', '2024-10-10 09:23:01');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (36, '小图发票类型', 'xt_invoice_type', '0', '长安银科', '', NULL, '2024-10-10 14:31:30', '2024-10-10 14:31:30');
INSERT INTO `sys_dict_type` (`id`, `dict_name`, `dict_type`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (37, '报关结关状态', 'declaration_status', '0', '长安银科', '', NULL, '2024-10-12 11:01:43', '2024-10-12 11:01:43');

-- ----------------------------
-- 12、字典数据表
-- ----------------------------
drop table if exists sys_dict_data;
create table sys_dict_data
(
    id    bigint(20) not null auto_increment comment '字典编码',
    dict_sort    int(4) default 0 comment '字典排序',
    dict_label   varchar(100) default '' comment '字典标签',
    dict_value   varchar(100) default '' comment '字典键值',
    dict_type    varchar(100) default '' comment '字典类型',
    css_class    varchar(100) default null comment '样式属性（其他样式扩展）',
    list_class   varchar(100) default null comment '表格回显样式',
    is_default   char(1)      default 'N' comment '是否默认（Y是 N否）',
    status       char(1)      default '0' comment '状态（0正常 1停用）',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '字典数据表';

INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (1, 1, '男', '0', 'sys_user_sex', '', '', 'Y', '0', 'admin', '', '性别男', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (2, 2, '女', '1', 'sys_user_sex', '', '', 'N', '0', 'admin', '', '性别女', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (3, 3, '未知', '2', 'sys_user_sex', '', '', 'N', '0', 'admin', '', '性别未知', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (4, 1, '显示', '0', 'sys_show_hide', '', 'primary', 'Y', '0', 'admin', '', '显示菜单', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (5, 2, '隐藏', '1', 'sys_show_hide', '', 'danger', 'N', '0', 'admin', '', '隐藏菜单', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (6, 1, '正常', '0', 'sys_normal_disable', '', 'primary', 'Y', '0', 'admin', '', '正常状态', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (7, 2, '停用', '1', 'sys_normal_disable', '', 'danger', 'N', '0', 'admin', '', '停用状态', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (8, 1, '正常', '0', 'sys_job_status', '', 'primary', 'Y', '0', 'admin', '', '正常状态', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (9, 2, '暂停', '1', 'sys_job_status', '', 'danger', 'N', '0', 'admin', '', '停用状态', '2024-05-25 16:58:25', '2024-05-25 16:58:25');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (10, 1, '默认', 'DEFAULT', 'sys_job_group', '', '', 'Y', '0', 'admin', '', '默认分组', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (11, 2, '系统', 'SYSTEM', 'sys_job_group', '', '', 'N', '0', 'admin', '', '系统分组', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (12, 1, '是', 'Y', 'sys_yes_no', '', 'primary', 'Y', '0', 'admin', '', '系统默认是', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (13, 2, '否', 'N', 'sys_yes_no', '', 'danger', 'N', '0', 'admin', '', '系统默认否', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (14, 1, '通知', '1', 'sys_notice_type', '', 'warning', 'Y', '0', 'admin', '', '通知', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (15, 2, '公告', '2', 'sys_notice_type', '', 'success', 'N', '0', 'admin', '', '公告', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (16, 1, '正常', '0', 'sys_notice_status', '', 'primary', 'Y', '0', 'admin', '', '正常状态', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (17, 2, '关闭', '1', 'sys_notice_status', '', 'danger', 'N', '0', 'admin', '', '关闭状态', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (18, 99, '其他', '0', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '', '其他操作', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (19, 1, '新增', '1', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '', '新增操作', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (20, 2, '修改', '2', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '', '修改操作', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (21, 3, '删除', '3', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '', '删除操作', '2024-05-25 16:58:26', '2024-05-25 16:58:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (22, 4, '授权', '4', 'sys_oper_type', '', 'primary', 'N', '0', 'admin', '', '授权操作', '2024-05-25 16:58:27', '2024-05-25 16:58:27');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (23, 5, '导出', '5', 'sys_oper_type', '', 'warning', 'N', '0', 'admin', '', '导出操作', '2024-05-25 16:58:27', '2024-05-25 16:58:27');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (24, 6, '导入', '6', 'sys_oper_type', '', 'warning', 'N', '0', 'admin', '', '导入操作', '2024-05-25 16:58:27', '2024-05-25 16:58:27');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (25, 7, '强退', '7', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '', '强退操作', '2024-05-25 16:58:27', '2024-05-25 16:58:27');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (26, 9, '清空数据', '9', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '', '清空操作', '2024-05-25 16:58:27', '2024-05-25 16:58:27');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (27, 1, '成功', '0', 'sys_common_status', '', 'primary', 'N', '0', 'admin', '', '正常状态', '2024-05-25 16:58:27', '2024-05-25 16:58:27');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (28, 2, '失败', '1', 'sys_common_status', '', 'danger', 'N', '0', 'admin', '', '停用状态', '2024-05-25 16:58:27', '2024-05-25 16:58:27');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (29, 1, '内资生产企业', '1', 'enterprise_type', NULL, NULL, 'Y', '0', 'ADMIN', '', '内资生产企业', '2024-05-27 20:11:10', '2024-09-14 16:10:37');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (30, 2, '外商投资生产企业', '2', 'enterprise_type', NULL, NULL, 'N', '0', 'ADMIN', '', '外商投资生产企业', '2024-05-27 20:11:10', '2024-09-14 16:10:39');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (31, 3, '外贸企业', '3', 'enterprise_type', NULL, NULL, 'N', '0', 'ADMIN', '', '外贸企业', '2024-05-27 20:11:10', '2024-09-14 16:10:43');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (32, 9, '其他企业', '9', 'enterprise_type', NULL, NULL, 'N', '0', 'ADMIN', '', '其他企业', '2024-05-27 20:11:10', '2024-09-14 16:10:46');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (33, 1, '进口', 'import', 'trade_type', NULL, NULL, 'Y', '0', 'ADMIN', '', '进口贸易', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (34, 2, '出口', 'export', 'trade_type', NULL, NULL, 'N', '0', 'ADMIN', '', '出口贸易', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (35, 1, '供应商', 'supplier', 'trade_relation_type', NULL, NULL, 'Y', '0', 'ADMIN', '', '供应商关系类型', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (36, 2, '进口商', 'importer', 'trade_relation_type', NULL, NULL, 'N', '0', 'ADMIN', '', '进口商关系类型', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (37, 1, '中国（不含港澳台地区）', 'CN', 'country_code', NULL, NULL, 'Y', '0', 'ADMIN', '', '中国（不含港澳台地区）', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (38, 2, '中国香港', 'HK', 'country_code', NULL, NULL, 'N', '0', 'ADMIN', '', '中国香港', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (39, 1, 'F理通', 'f_trade', 'business_product', NULL, NULL, 'Y', '0', 'ADMIN', '', 'F理通', '2024-05-27 20:11:10', '2024-09-05 15:46:53');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (40, 2, '贸服通', 'e_trade', 'business_product', NULL, NULL, 'N', '0', 'ADMIN', '', '贸服通', '2024-05-27 20:11:10', '2024-09-05 15:46:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (41, 3, '跨境贸易', 'cross_border_trade', 'business_product', NULL, NULL, 'N', '0', 'ADMIN', '', '跨境贸易', '2024-05-27 20:11:10', '2024-05-27 20:44:03');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (43, 1, '自营出口', 'self_export', 'export_type', NULL, NULL, 'Y', '0', 'ADMIN', '', '自营出口', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (44, 2, '代理出口', 'proxy_export', 'export_type', NULL, NULL, 'N', '0', 'ADMIN', '', '代理出口', '2024-05-27 20:11:10', '2024-09-05 10:49:57');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (45, 1, '自营生产', 'self_product', 'goods_source', NULL, NULL, 'Y', '0', 'ADMIN', '', '自营生产', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (46, 2, '厂商采购', 'procurement', 'goods_source', NULL, NULL, 'N', '0', 'ADMIN', '', '自营生产', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (47, 1, '身份证', 'psn_cn_idcard', 'personal_cert_type', NULL, NULL, 'Y', '0', 'ADMIN', '', '身份证', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (48, 2, '护照', 'psn_passport', 'personal_cert_type', NULL, NULL, 'N', '0', 'ADMIN', '', '护照', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (49, 1, '未婚', '0', 'marriage_status', NULL, NULL, 'Y', '0', 'ADMIN', '', '未婚', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (50, 2, '已婚', '1', 'marriage_status', NULL, NULL, 'N', '0', 'ADMIN', '', '已婚', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (51, 3, '离异', '2', 'marriage_status', NULL, NULL, 'N', '0', 'ADMIN', '', '离异', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (52, 4, '丧偶', '3', 'marriage_status', NULL, NULL, 'N', '0', 'ADMIN', '', '丧偶', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (53, 99, '未知', '99', 'marriage_status', NULL, NULL, 'N', '0', 'ADMIN', '', '未知', '2024-05-27 20:11:10', '2024-05-27 20:12:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (54, 1, '家电产品', '01', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '家电产品', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (55, 2, '摩托车', '02', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '摩托车', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (56, 3, '医药保健品', '03', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '医药保健品', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (57, 4, '钢铁', '04', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '钢铁', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (58, 5, '家具', '05', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '家具', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (59, 6, '汽车零部件', '06', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '汽车零部件', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (60, 7, '农药', '07', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '农药', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (61, 8, '其他通讯品', '08', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '其他通讯品', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (62, 9, '电脑', '09', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '电脑', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (63, 10, '陶瓷', '10', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '陶瓷', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (64, 11, '汽车整车或成套散件', '11', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '汽车整车或成套散件', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (65, 12, '纺织原料及半成品', '12', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '纺织原料及半成品', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (66, 13, '皮革', '13', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '皮革', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (67, 14, '光伏产品', '14', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '光伏产品', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (68, 15, '纺织成品', '15', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '纺织成品', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (69, 16, '农产品', '16', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '农产品', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (70, 17, '燃料油', '17', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '燃料油', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (71, 18, '鞋靴', '18', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '鞋靴', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (72, 19, '工程机械及其零部件', '19', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '工程机械及其零部件', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (73, 20, '化肥', '20', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '化肥', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (74, 21, '船舶及修理', '21', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '船舶及修理', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (75, 22, '印刷电路板及原材料', '22', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '印刷电路板及原材料', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (76, 23, '玩具', '23', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '玩具', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (77, 24, '手机及电话', '24', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '手机及电话', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (78, 25, '其他基本金属及贵金属', '25', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '其他基本金属及贵金属', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (79, 99, '其他', '99', 'business_category', NULL, NULL, 'N', '0', 'ADMIN', '', '其他', '2024-05-29 14:37:50', '2024-05-29 14:37:50');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (80, 1, '未认证', 'not_certification', 'certification_status', NULL, NULL, 'Y', '0', 'ADMIN', '', '未认证', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (81, 2, '认证中', 'in_certification', 'certification_status', NULL, NULL, 'N', '0', 'ADMIN', '', '认证中', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (82, 3, '认证通过', 'passed_certification', 'certification_status', NULL, NULL, 'N', '0', 'ADMIN', '', '认证通过', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (83, 4, '认证不通过', 'failed_certification', 'certification_status', NULL, NULL, 'N', '0', 'ADMIN', '', '认证不通过', '2024-05-29 14:37:49', '2024-05-29 14:37:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (84, 1, '中国大陆', 'CN_MAINLAND', 'district_code', NULL, NULL, 'Y', '0', 'ADMIN', '', '中国大陆', '2024-06-05 14:56:27', '2024-09-05 16:10:55');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (87, 2, '中国香港', 'CN_HK', 'district_code', NULL, NULL, 'N', '0', 'ADMIN', '', '中国香港', '2024-06-05 14:56:28', '2024-09-05 16:10:58');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (88, 3, '中国澳门', 'CN_MO', 'district_code', NULL, NULL, 'N', '0', 'ADMIN', '', '中国澳门', '2024-06-05 14:56:28', '2024-09-05 16:11:01');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (89, 4, '中国台湾', 'CN_TW', 'district_code', NULL, NULL, 'N', '0', 'ADMIN', '', '中国台湾', '2024-06-05 14:56:28', '2024-09-05 16:11:03');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (90, 5, '中国境外', 'FOREIGN', 'district_code', NULL, NULL, 'N', '0', 'ADMIN', '', '中国境境外', '2024-06-05 14:56:28', '2024-09-05 16:11:10');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (100, 1, '客户推荐码前缀地址', 'https://demo.changyin.tech/#/home/register/', 'customer_register_prefix', '', '', 'Y', '0', 'admin', '', '客户推荐码前缀地址', '2024-06-06 09:58:19', '2024-06-06 09:58:19');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (101, 0, '短期出口信用保险', '01', 'insurance_type', NULL, NULL, 'Y', '0', 'ADMIN', '', '短期出口信用保险', '2024-06-11 15:03:48', '2024-06-11 15:03:48');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (102, 1, '中小企业综合保险', '02', 'insurance_type', NULL, NULL, 'N', '0', 'ADMIN', '', '中小企业综合保险', '2024-06-11 15:04:01', '2024-06-11 15:04:42');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (103, 1, '合同签订时', '1', 'payment_time', '', '', 'Y', '0', 'admin', '', '合同签订时', '2024-09-09 16:06:58', '2024-09-09 16:06:58');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (104, 2, '装运前', '2', 'payment_time', '', '', 'Y', '0', 'admin', '', '装运前', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (105, 3, '装船时', '3', 'payment_time', '', '', 'Y', '0', 'admin', '', '装船时', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (106, 4, '装运后提单', '4', 'payment_time', '', '', 'Y', '0', 'admin', '', '装运后提单', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (107, 5, '货物到达目的地', '5', 'payment_time', '', '', 'Y', '0', 'admin', '', '货物到达目的地', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (108, 6, '见票后', '6', 'payment_time', '', '', 'Y', '0', 'admin', '', '见票后', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (109, 7, '信用证到期后', '7', 'payment_time', '', '', 'Y', '0', 'admin', '', '信用证到期后', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (110, 8, '货物交付后', '8', 'payment_time', '', '', 'Y', '0', 'admin', '', '货物交付后', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (111, 9, '货物检验合格后', '9', 'payment_time', '', '', 'Y', '0', 'admin', '', '货物检验合格后', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (112, 10, '其他付款时点', '10', 'payment_time', '', '', 'Y', '0', 'admin', '', '其他付款时点', '2024-09-09 16:06:59', '2024-09-09 16:06:59');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (113, 0, '草稿', '0', 'purchase_contract_status', NULL, NULL, 'Y', '0', 'admin', '', '草稿', '2024-09-10 19:10:18', '2024-09-10 19:12:52');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (114, 1, '待上传合同', '1', 'purchase_contract_status', NULL, NULL, 'N', '0', 'admin', '', '待上传合同', '2024-09-10 19:10:25', '2024-09-10 19:13:45');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (115, 2, '合同签署中', '2', 'purchase_contract_status', NULL, NULL, 'N', '0', 'admin', '', '合同签署中', '2024-09-10 19:10:37', '2024-09-10 19:13:46');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (116, 3, '合同签署超时', '3', 'purchase_contract_status', NULL, NULL, 'N', '0', 'admin', '', '合同签署超时', '2024-09-10 19:10:43', '2024-09-10 19:13:48');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (117, 4, '已完成', '4', 'purchase_contract_status', NULL, NULL, 'N', '0', 'admin', '', '已完成', '2024-09-10 19:10:48', '2024-09-10 19:13:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (119, 0, '北京', '11100000000', 'tax_authority_area', NULL, NULL, 'Y', '0', 'admin', '', '北京', '2024-09-20 10:53:33', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (120, 1, '天津', '11200000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '天津', '2024-09-20 10:53:33', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (121, 2, '河北', '11300000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '河北', '2024-09-20 10:53:33', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (122, 3, '内蒙古', '11500000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '内蒙古', '2024-09-20 10:53:33', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (123, 4, '大连', '12102000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '大连', '2024-09-20 10:53:33', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (124, 5, '辽宁', '12100000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '辽宁', '2024-09-20 10:53:33', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (125, 6, '吉林', '12200000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '吉林', '2024-09-20 10:53:33', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (126, 7, '黑龙江', '12300000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '黑龙江', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (127, 8, '上海', '13100000000', 'tax_authority_area', NULL, NULL, 'Y', '0', 'admin', '', '上海', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (128, 9, '宁波', '13302000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '宁波', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (129, 10, '安徽', '13400000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '安徽', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (130, 11, '厦门', '13502000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '厦门', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (131, 12, '福建', '13500000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '福建', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (132, 13, '江西', '13600000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '江西', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (133, 14, '青岛', '13702000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '青岛', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (134, 15, '山东', '13700000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '山东', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (135, 16, '河南', '14100000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '河南', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (136, 17, '湖北', '14200000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '湖北', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (137, 18, '湖南', '14300000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '湖南', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (138, 19, '广东', '14400000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '广东', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (139, 20, '深圳', '14403000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '深圳', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (140, 21, '海南', '14600000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '海南', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (141, 22, '重庆', '15000000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '重庆', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (142, 23, '贵州', '15200000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '贵州', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (143, 24, '陕西', '16100000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '陕西', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (144, 25, '甘肃', '16200000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '甘肃', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (145, 26, '青海', '16300000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '青海', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (146, 27, '宁夏', '16400000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '宁夏', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (147, 28, '新疆', '16500000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '新疆', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (148, 29, '广西', '14500000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '广西', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (149, 30, '四川', '15100000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '四川', '2024-09-20 10:53:34', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (150, 31, '云南', '15300000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '云南', '2024-09-20 10:53:35', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (151, 32, '山西', '11400000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '山西', '2024-09-20 10:53:35', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (152, 33, '江苏', '13200000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '江苏', '2024-09-20 10:53:35', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (153, 34, '浙江', '13300000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '浙江', '2024-09-20 10:53:35', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (154, 35, '西藏', '15400000000', 'tax_authority_area', NULL, NULL, 'N', '0', 'admin', '', '西藏', '2024-09-20 10:53:35', '2024-09-20 10:55:06');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (155, 1, 'L/C信用证', '1', 'payment_way', '', '', 'Y', '0', 'admin', '', 'L/C信用证', '2024-09-24 16:23:04', '2024-09-24 16:23:04');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (156, 2, 'T/T电汇', '2', 'payment_way', '', '', 'Y', '0', 'admin', '', 'T/T电汇', '2024-09-24 16:23:04', '2024-09-24 16:23:04');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (157, 3, 'D/P付款交单', '3', 'payment_way', '', '', 'Y', '0', 'admin', '', 'D/P付款交单', '2024-09-24 16:23:04', '2024-09-24 16:23:04');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (158, 4, 'D/A承兑交单', '4', 'payment_way', '', '', 'Y', '0', 'admin', '', 'D/A承兑交单', '2024-09-24 16:23:04', '2024-09-24 16:23:04');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (159, 5, 'O/A赊销付款', '5', 'payment_way', '', '', 'Y', '0', 'admin', '', 'O/A赊销付款', '2024-09-24 16:23:04', '2024-09-24 16:23:04');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (160, 6, 'Collection托收', '6', 'payment_way', '', '', 'Y', '0', 'admin', '', 'Collection托收', '2024-09-24 16:23:04', '2024-09-24 16:23:04');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (161, 7, '其他', '7', 'payment_way', '', '', 'Y', '0', 'admin', '', '其他', '2024-09-24 16:23:04', '2024-09-24 16:23:04');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (162, 0, 'CNY', 'CNY', 'currency_code', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-09-24 19:40:30', '2024-09-24 19:40:30');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (163, 1, 'USD', 'USD', 'currency_code', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-09-24 19:40:40', '2024-09-24 19:40:40');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (164, 0, '未签署', '0', 'sys_sign_status', NULL, 'info', 'N', '0', '长安银科', '长安银科', '未发起签署', '2024-09-26 15:52:10', '2024-09-26 15:56:09');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (165, 0, '签署中', '1', 'sys_sign_status', NULL, 'primary', 'N', '0', '长安银科', '长安银科', '已发送签署链接', '2024-09-26 15:52:25', '2024-09-26 15:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (166, 0, '签署成功', '2', 'sys_sign_status', NULL, 'success', 'N', '0', '长安银科', '长安银科', '完成签署', '2024-09-26 15:53:17', '2024-09-26 15:56:02');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (167, 0, '签署超时', '3', 'sys_sign_status', NULL, 'warning', 'N', '0', '长安银科', '长安银科', '超时未签署', '2024-09-26 15:53:57', '2024-09-26 15:55:32');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (168, 0, '拒绝签署', '4', 'sys_sign_status', NULL, 'warning', 'N', '0', '长安银科', '长安银科', '用户拒签', '2024-09-26 15:54:52', '2024-09-26 15:55:38');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (169, 0, '签署失败', '5', 'sys_sign_status', NULL, 'danger', 'N', '0', '长安银科', '', '未知原因签署失败', '2024-09-26 15:55:23', '2024-09-26 15:55:23');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (170, 1, 'EXW', 'EXW', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'EXW', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (171, 2, 'ECA', 'ECA', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'ECA', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (172, 3, 'FAS', 'FAS', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'FAS', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (173, 4, 'FOB', 'FOB', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'FOB', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (174, 5, 'CFR', 'CFR', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'CFR', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (175, 6, 'CIF', 'CIF', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'CIF', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (176, 7, 'CPT', 'CPT', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'CPT', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (177, 8, 'CIP', 'CIP', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'CIP', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (178, 9, 'DAT', 'DAT', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'DAT', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (179, 10, 'DAP', 'DAP', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'DAP', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (180, 11, 'DDP', 'DDP', 'trade_terms', '', '', 'Y', '0', 'admin', '', 'DDP', '2024-09-26 19:55:51', '2024-09-26 19:55:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (181, 0, '增值税专用发票', '1', 'invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-09-28 16:46:56', '2024-09-28 16:46:56');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (182, 1, '增值税普通发票', '2', 'invoice_type', NULL, 'default', 'N', '0', '长安银科', '长安银科', NULL, '2024-09-28 16:47:09', '2024-09-28 16:47:15');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (183, 1, '草稿', '1', 'sales_contract_status', '', '', 'Y', '0', 'admin', '', '草稿', '2024-09-29 14:41:32', '2024-09-29 14:42:55');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (184, 2, '生效', '2', 'sales_contract_status', '', '', 'Y', '0', 'admin', '', '生效', '2024-09-29 14:41:32', '2024-09-29 14:42:55');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (185, 3, '待上传', '3', 'sales_contract_status', '', '', 'Y', '0', 'admin', '', '待上传', '2024-09-29 14:41:32', '2024-09-29 14:42:55');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (186, 4, '合同签署超时', '4', 'sales_contract_status', '', '', 'Y', '0', 'admin', '', '合同签署超时', '2024-09-29 14:41:32', '2024-09-29 14:42:55');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (187, 5, '合同签署中', '5', 'sales_contract_status', '', '', 'Y', '0', 'admin', '', '合同签署中', '2024-09-29 14:41:32', '2024-09-29 14:42:55');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (188, 6, '已完成', '6', 'sales_contract_status', '', '', 'Y', '0', 'admin', '', '已完成', '2024-09-29 14:41:32', '2024-09-29 14:42:55');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (189, 0, '待生效', '0', 'sales_order_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 09:23:32', '2024-10-10 09:23:32');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (190, 1, '待发货', '1', 'sales_order_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 09:23:53', '2024-10-10 09:23:53');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (191, 2, '运输中', '2', 'sales_order_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 09:24:14', '2024-10-10 09:24:14');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (192, 3, '交易完成', '3', 'sales_order_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 09:24:32', '2024-10-10 09:24:32');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (193, 2, '增值税电子专用发票', '3', 'invoice_type', NULL, 'default', 'N', '0', '长安银科', '长安银科', NULL, '2024-10-10 14:28:25', '2024-10-10 14:29:23');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (194, 3, '增值税电子普通发票', '4', 'invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:29:47', '2024-10-10 14:29:47');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (195, 4, '数电票（增值税专用发票）', '5', 'invoice_type', NULL, 'default', 'N', '0', '长安银科', '长安银科', NULL, '2024-10-10 14:30:05', '2024-10-14 10:07:12');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (196, 5, '数电票（增值税普通发票）', '6', 'invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:30:21', '2024-10-10 14:30:21');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (197, 0, '增值税专用发票', '01', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:32:17', '2024-10-10 14:32:17');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (198, 1, '货物运输业增值税专用发票', '02', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:32:36', '2024-10-10 14:32:36');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (199, 2, '机动车销售统一发票', '03', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:33:13', '2024-10-10 14:33:13');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (200, 3, '增值税普通发票', '04', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:33:39', '2024-10-10 14:33:39');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (201, 4, '增值税电子专用发票', '08', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '长安银科', NULL, '2024-10-10 14:34:07', '2024-10-10 14:34:28');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (202, 5, '增值税电子普通发票', '10', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:34:47', '2024-10-10 14:34:47');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (203, 6, '卷式发票', '11', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:35:19', '2024-10-10 14:35:19');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (204, 7, '通行费发票', '14', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:35:46', '2024-10-10 14:35:46');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (205, 8, '二手车销售统一发票', '15', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:36:51', '2024-10-10 14:36:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (206, 9, '电子发票(铁路电子客票)', '51', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:37:19', '2024-10-10 14:37:19');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (207, 10, '电子发票(航空运输客票电子发票）', '61', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:38:00', '2024-10-10 14:38:00');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (208, 11, '电子发票(增值税专用发票)', '81', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:38:30', '2024-10-10 14:38:30');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (209, 12, '电子发票(普通发票)', '82', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:39:22', '2024-10-10 14:39:22');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (210, 13, '机动车销售电子统一发票', '83', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:39:47', '2024-10-10 14:39:47');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (211, 14, '二手车销售电子统一发票', '84', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '长安银科', NULL, '2024-10-10 14:40:13', '2024-10-10 14:40:19');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (212, 15, '纸质发票(增值税专用发票)', '85', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:41:04', '2024-10-10 14:41:04');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (213, 16, '纸质发票(普通发票)', '86', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:41:26', '2024-10-10 14:41:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (214, 17, '纸质发票(机动车销售统一发票)', '87', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:42:12', '2024-10-10 14:42:12');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (215, 18, '纸质发票(二手车销售统一发票)', '88', 'xt_invoice_type', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-10 14:42:43', '2024-10-10 14:42:43');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (216, 0, '保存', '1', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:03:14', '2024-10-15 14:03:14');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (217, 1, '已申报', '2', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:03:35', '2024-10-15 14:03:35');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (218, 2, '预录入接收失败', '3', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:03:47', '2024-10-15 14:03:47');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (219, 3, '海关入库成功', '4', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:03:58', '2024-10-15 14:03:58');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (220, 4, '海关入库失败', '5', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:04:13', '2024-10-15 14:04:13');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (221, 5, '退单', '6', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:04:26', '2024-10-15 14:04:26');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (222, 6, '审结', '7', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:04:36', '2024-10-15 14:04:36');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (223, 7, '删单', '8', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:04:49', '2024-10-15 14:04:49');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (224, 8, '放行', '9', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:06:41', '2024-10-15 14:06:41');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (225, 9, '结关', '10', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:06:51', '2024-10-15 14:06:51');
INSERT INTO `sys_dict_data` (`id`, `dict_sort`, `dict_label`, `dict_value`, `dict_type`, `css_class`, `list_class`, `is_default`, `status`, `create_by`, `update_by`, `remark`, `gmt_create`, `gmt_modified`) VALUES (226, 10, '查验通知', '11', 'declaration_status', NULL, 'default', 'N', '0', '长安银科', '', NULL, '2024-10-15 14:07:02', '2024-10-15 14:07:02');


-- ----------------------------
-- 13、参数配置表
-- ----------------------------
drop table if exists sys_config;
create table sys_config
(
    id    int(5) not null auto_increment comment '参数主键',
    config_name  varchar(100) default '' comment '参数名称',
    config_key   varchar(100) default '' comment '参数键名',
    config_value varchar(500) default '' comment '参数键值',
    config_type  char(1)      default 'N' comment '系统内置（Y是 N否）',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '参数配置表';

insert into sys_config values(1, '主框架页-默认皮肤样式名称',     'sys.index.skinName',            'skin-blue',     'Y', 'admin',  '', '蓝色 skin-blue、绿色 skin-green、紫色 skin-purple、红色 skin-red、黄色 skin-yellow' , sysdate(),sysdate());
insert into sys_config values(2, '用户管理-账号初始密码',         'sys.user.initPassword',         '123456',        'Y', 'admin',  '', '初始化密码 123456' , sysdate(),sysdate());
insert into sys_config values(3, '主框架页-侧边栏主题',           'sys.index.sideTheme',           'theme-dark',    'Y', 'admin',  '', '深色主题theme-dark，浅色主题theme-light' , sysdate(),sysdate());
insert into sys_config values(4, '账号自助-验证码开关',           'sys.account.captchaEnabled',    'true',          'Y', 'admin',  '', '是否开启验证码功能（true开启，false关闭）', sysdate(),sysdate());
insert into sys_config values(5, '账号自助-是否开启用户注册功能', 'sys.account.registerUser',      'false',         'Y', 'admin',  '', '是否开启注册用户功能（true开启，false关闭）', sysdate(),sysdate());
insert into sys_config values(6, '用户登录-黑名单列表',           'sys.login.blackIPList',         '',              'Y', 'admin',  '', '设置登录IP黑名单限制，多个匹配项以;分隔，支持匹配（*通配、网段）', sysdate(),sysdate());


-- ----------------------------
-- 14、系统访问记录
-- ----------------------------
drop table if exists sys_logininfor;
create table sys_logininfor
(
    id        bigint(20) not null auto_increment comment '访问ID',
    user_name      varchar(50)  default '' comment '用户账号',
    ipaddr         varchar(128) default '' comment '登录IP地址',
    login_location varchar(255) default '' comment '登录地点',
    browser        varchar(50)  default '' comment '浏览器类型',
    os             varchar(50)  default '' comment '操作系统',
    status         char(1)      default '0' comment '登录状态（0成功 1失败）',
    msg            varchar(255) default '' comment '提示消息',
    login_time     datetime comment '访问时间',
    gmt_create     TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id),
    key            idx_sys_logininfor_s (status),
    key            idx_sys_logininfor_lt (login_time)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '系统访问记录';

-- ----------------------------
-- 15、通知公告表
-- ----------------------------
drop table if exists sys_notice;
create table sys_notice
(
    id      int(4) not null auto_increment comment '公告ID',
    notice_title   varchar(50) not null comment '公告标题',
    notice_type    char(1)     not null comment '公告类型（1通知 2公告）',
    notice_content longblob     default null comment '公告内容',
    status         char(1)      default '0' comment '公告状态（0正常 1关闭）',
    create_by      varchar(64)  default '' comment '创建者',
    update_by      varchar(64)  default '' comment '更新者',
    remark         varchar(255) default null comment '备注',
    gmt_create     TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '通知公告表';
