-- 进口商企业信息
DROP TABLE IF EXISTS `importer_entity`;
CREATE TABLE `importer_entity`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `customer_user_id`         BIGINT(20)  UNSIGNED NOT NULL COMMENT '用户id',
    `entity_no`            VARCHAR(16)        DEFAULT '' COMMENT '企业编号',
    `region`            VARCHAR(16)        DEFAULT '' COMMENT '地区 1中国香港 2中国澳门 3中国台湾 4中国境外',
    `country`            VARCHAR(4)        DEFAULT '' COMMENT '国家',
    `status`            TINYINT(3)        DEFAULT 0 COMMENT '状态 0待生效/1生效',
    `entity_name`            VARCHAR(64)        DEFAULT '' COMMENT '企业名称',
    `cert_type`            VARCHAR(32)        DEFAULT '' COMMENT '企业证件类型',
    `cert_no`            VARCHAR(32)        DEFAULT '' COMMENT '企业证件号',
    `business_province`  	VARCHAR(64)        DEFAULT '' COMMENT '经营地址（省 / 州 / 区）',
    `business_city`  	VARCHAR(64)        DEFAULT '' COMMENT '经营地址（市 / 区）',
    `business_address`  	VARCHAR(64)        DEFAULT '' COMMENT '经营地址',
    `business_post_code`  	VARCHAR(64)        DEFAULT '' COMMENT '经营地址邮政编码',
    `contact_direct_ind`  VARCHAR(1)        DEFAULT '' COMMENT '是否允许直接联系',
    `contact_name`  		VARCHAR(32)        DEFAULT '' COMMENT '企业联系人姓名',
    `contact_mobile`  	VARCHAR(18)        DEFAULT '' COMMENT '企业联系人手机号',
    `contact_email`  		VARCHAR(64)        DEFAULT '' COMMENT '企业联系人邮箱',
    `vat_no`  		VARCHAR(64)        DEFAULT '' COMMENT '税号',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY uk_importer_entity_no (`entity_no`),
    INDEX idx_user_id(`customer_user_id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='进口商企业信息';





-- 供应商企业信息
DROP TABLE IF EXISTS `vendor_entity`;
CREATE TABLE `vendor_entity`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `customer_user_id`         BIGINT(20)  UNSIGNED NOT NULL COMMENT '用户id',
    `entity_no`            VARCHAR(16)        DEFAULT '' COMMENT '企业编号',
    `entity_name`            VARCHAR(64)        DEFAULT '' COMMENT '企业名称',
    `cert_no`            VARCHAR(32)        DEFAULT '' COMMENT '企业证件号',
    `contact_name`  		VARCHAR(32)        DEFAULT '' COMMENT '企业联系人姓名',
    `contact_cert_no`  		VARCHAR(32)        DEFAULT '' COMMENT '企业联系人证件号',
    `contact_mobile`  	VARCHAR(18)        DEFAULT '' COMMENT '企业联系人手机号',
    `contact_email`  		VARCHAR(64)        DEFAULT '' COMMENT '企业联系人邮箱',
    `acct_name`  		VARCHAR(64)        DEFAULT '' COMMENT '收款账户户名',
    `acct_no`  		VARCHAR(32)        DEFAULT '' COMMENT '收款银行卡号',
    `acct_open_bank`  		VARCHAR(64)        DEFAULT '' COMMENT '收款账户开户行',
    `business_address`  	VARCHAR(64)        DEFAULT '' COMMENT '经营地址',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY uk_vendor_entity_no (`entity_no`),
    INDEX idx_user_id(`customer_user_id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='供应商企业信息';







-- 销售订单
DROP TABLE IF EXISTS `sales_order`;
CREATE TABLE `sales_order`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `customer_user_id`         BIGINT(20)  UNSIGNED NOT NULL COMMENT '用户id',
    `order_no`            VARCHAR(32)        DEFAULT NULL COMMENT '订单编号',
    `importer_id`            BIGINT(20)  UNSIGNED DEFAULT NULL COMMENT '进口商id',
    `sale_contract_id`       BIGINT(20)  UNSIGNED DEFAULT NULL COMMENT '销售合同id',
    `amount`            DECIMAL(17,2)        DEFAULT '0.00' COMMENT '订单金额',
    `status`            TINYINT(3)        DEFAULT 0 COMMENT '状态 0待生效/1待发货/2运输中/3交易完成',
    `customs_declaration_status` TINYINT(1) DEFAULT 0 COMMENT '报关单拉取状态',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `create_by`                varchar(64)     default '' comment '创建者',
    `update_by`                varchar(64)     default '' comment '更新者',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY uk_order_no (`order_no`),
    INDEX idx_user_id(`customer_user_id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='销售订单表';





-- 销售订单-关联商品
DROP TABLE IF EXISTS `sales_order_goods`;
CREATE TABLE `sales_order_goods`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `sale_order_id`         BIGINT(20)  UNSIGNED NOT NULL COMMENT '销售订单id',
    `sales_commodity_id`         BIGINT(20)  UNSIGNED NOT NULL COMMENT '销售合同商品id',
    `vendor_entity_no`            VARCHAR(32)        DEFAULT '' COMMENT '供应商编号',
    `hs_code`            VARCHAR(32)  DEFAULT '' COMMENT 'HS CODE',
    `declaration_name`            VARCHAR(32)  DEFAULT '' COMMENT '报关品名',
    `name`            VARCHAR(32)  DEFAULT '' COMMENT '商品名称',
    `unit`            VARCHAR(32)  DEFAULT '' COMMENT '计量单位',
    `packing_specifications`            VARCHAR(16)  DEFAULT '' COMMENT '包装规格',
    `price`            DECIMAL(17,2)   DEFAULT '0' COMMENT '销售单价',
    `tax_refund_rate`            DECIMAL(8,6)   DEFAULT '0' COMMENT '退税率',
    `count`            SMALLINT(6)   DEFAULT '0' COMMENT '商品数量',
    `price_total`            DECIMAL(17,2)   DEFAULT '0' COMMENT '商品总额',
    `model`            VARCHAR(32)  DEFAULT '' COMMENT '型号',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    INDEX idx_sale_order_id (`sale_order_id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='销售订单-关联商品';


-- 销售订单-物流信息
DROP TABLE IF EXISTS `sales_order_logistics`;
CREATE TABLE `sales_order_logistics`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `order_id`         BIGINT(20)  UNSIGNED NOT NULL COMMENT '销售订单id',
    `logistics_company`            VARCHAR(64)        DEFAULT '' COMMENT '物流公司',
    `deliver_time`            datetime        DEFAULT null COMMENT '发货时间',
    `from_port`            VARCHAR(64)        DEFAULT '' COMMENT '启运港',
    `dest_port`  	VARCHAR(64)        DEFAULT '' COMMENT '目的港',
    `lading_bill_no`  	VARCHAR(64)        DEFAULT '' COMMENT '提单号',
    `lading_bill_file_id`  	 BIGINT(20)  UNSIGNED DEFAULT null COMMENT '提单文件id',
    `estimated_arrival_time`  	datetime        DEFAULT null COMMENT '预计送达日期',
    `deliver_remark`  	VARCHAR(128)        DEFAULT '' COMMENT '发货备注',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    INDEX idx_order_id (`order_id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='销售订单-物流信息';




-- 销售订单-发票信息
DROP TABLE IF EXISTS `sales_order_invoice`;
CREATE TABLE `sales_order_invoice`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `order_id`         BIGINT(20)  UNSIGNED NOT NULL COMMENT '销售订单id',
    `invoice_no`            VARCHAR(32)        DEFAULT '' COMMENT '发票号码',
    `amount`             DECIMAL(17,2)   DEFAULT '0' COMMENT '发票金额',
    `file_id`            BIGINT(20)  UNSIGNED NOT NULL COMMENT '发票文件id',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY uk_invoice_no (`invoice_no`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='销售订单-发票信息';




-- 销售订单-物流-集装箱信息
DROP TABLE IF EXISTS `sales_order_container`;
CREATE TABLE `sales_order_container`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `logistics_id`         BIGINT(20)  UNSIGNED NOT NULL COMMENT '订单物流id',
    `bill_no`            VARCHAR(32)        DEFAULT '' COMMENT '集装箱单号',
    `file_id`            BIGINT(20)  UNSIGNED NOT NULL COMMENT '集装箱单文件id',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    INDEX idx_logistics_id (`logistics_id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='销售订单-集装箱信息';





-- 文件模板配置
DROP TABLE IF EXISTS `s_file_template`;
CREATE TABLE `s_file_template`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `template_code`         VARCHAR(32)        not null COMMENT '模板编号',
    `file_type`           VARCHAR(32)  	DEFAULT '' COMMENT '文件类型',
    `default_name`           VARCHAR(32)  	DEFAULT '' COMMENT '生成文件默认名称',
    `src_path`            VARCHAR(128)        DEFAULT '' COMMENT '模板绝对路径',
    `dest_dir`            VARCHAR(64)   DEFAULT '' COMMENT '生成文件存储目录',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='文件模板配置';




-- 报关单
DROP TABLE IF EXISTS `customs_declaration`;
CREATE TABLE `customs_declaration`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `sale_order_no`            VARCHAR(32)        DEFAULT '' COMMENT '销售订单no,对应小图合同号',
    `related_entry_ind`        TINYINT(1)        DEFAULT 0 COMMENT '是否已关联入账',
    `bgsbzt_dm`            VARCHAR(16)        DEFAULT '' COMMENT '报关申报状态代码',
    `bgdhgbh`            VARCHAR(32)        DEFAULT '' COMMENT '报关单海关编号',
    `hgqy_dm`            VARCHAR(32)        DEFAULT '' COMMENT '海关企业代码',
    `ckrq1`            VARCHAR(16)        DEFAULT '' COMMENT '出口日期',
    `sbhggqka_dm`            VARCHAR(64)        DEFAULT '' COMMENT '申报海关关区（口岸）代码',
    `sbhggqkajc`            VARCHAR(32)        DEFAULT '' COMMENT '申报海关关区（口岸）简称',
    `yfje`            DECIMAL(17,2)        DEFAULT 0 COMMENT '运费金额',
    `yfhghbzm_dm`  	VARCHAR(64)        DEFAULT '' COMMENT '运费海关货币字母代码',
    `bfje`  	DECIMAL(17,2)        DEFAULT 0 COMMENT '保费金额',
    `bfhghbzm_dm`  	VARCHAR(64)        DEFAULT '' COMMENT '保费海关货币字母代码',
    `zfje1`  	DECIMAL(17,2)        DEFAULT 0 COMMENT '杂费金额',
    `zfhghbzm_dm`  VARCHAR(64)        DEFAULT '' COMMENT '杂费海关货币字母代码',
    `js1`  		SMALLINT(10)        DEFAULT 0 COMMENT '件数',
    `mz2`  	SMALLINT(10)        DEFAULT 0 COMMENT '毛重（千克）',
    `jz`  	SMALLINT(10)        DEFAULT 0 COMMENT '净重（千克）',
    `hgckhwbgdsbrq`  		VARCHAR(16)        DEFAULT '' COMMENT '海关出口货物报关单申报日期',
    `sbdwmc`  		VARCHAR(64)        DEFAULT '' COMMENT '申报单位名称',
    `jzxh`  		VARCHAR(256)        DEFAULT '' COMMENT '集装箱号',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    INDEX idx_sale_order_no(`sale_order_no`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='报关单信息';



-- 报关单商品
DROP TABLE IF EXISTS `customs_declaration_goods`;
CREATE TABLE `customs_declaration_goods`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `sale_order_no`            VARCHAR(32)        DEFAULT '' COMMENT '销售订单no,对应小图合同号',
    `hgcksp_dm`            VARCHAR(32)        DEFAULT '' COMMENT '海关出口商品代码，对应销售订单商品hs_code',
    `xh4`            VARCHAR(16)        DEFAULT '' COMMENT '项号',
    `ckbgdh`            VARCHAR(32)        DEFAULT '' COMMENT '出口报关单号',
    `bgsbzt_dm`            VARCHAR(16)        DEFAULT '' COMMENT '报关申报状态代码',
    `hgspmc`            VARCHAR(64)        DEFAULT '' COMMENT '海关商品名称',
    `ggxh`            VARCHAR(64)        DEFAULT '' COMMENT '规格型号',
    `hgjldwmc`            VARCHAR(64)        DEFAULT '' COMMENT '海关计量单位名称',
    `dyjldw_dm`            VARCHAR(32)        DEFAULT '' COMMENT '第一计量单位代码',
    `cksl`            SMALLINT(10)        DEFAULT 0 COMMENT '出口数量',
    `bgdhgbh`            VARCHAR(32)        DEFAULT '' COMMENT '报关单海关编号',
    `hgqy_dm`            VARCHAR(32)        DEFAULT '' COMMENT '海关企业代码',
    `ckrq1`            VARCHAR(16)        DEFAULT '' COMMENT '出口日期',
    `sbhggqka_dm`            VARCHAR(64)        DEFAULT '' COMMENT '申报海关关区（口岸）代码',
    `sbhggqkajc`            VARCHAR(32)        DEFAULT '' COMMENT '申报海关关区（口岸）简称',
    `yfje`            DECIMAL(17,2)        DEFAULT 0 COMMENT '运费金额',
    `yfhghbzm_dm`  	VARCHAR(64)        DEFAULT '' COMMENT '运费海关货币字母代码',
    `bfje`  	DECIMAL(17,2)        DEFAULT 0 COMMENT '保费金额',
    `bfhghbzm_dm`  	VARCHAR(64)        DEFAULT '' COMMENT '保费海关货币字母代码',
    `zfje1`  	DECIMAL(17,2)        DEFAULT 0 COMMENT '杂费金额',
    `zfhghbzm_dm`  VARCHAR(64)        DEFAULT '' COMMENT '杂费海关货币字母代码',
    `js1`  		SMALLINT(10)        DEFAULT 0 COMMENT '件数',
    `mz2`  	SMALLINT(10)        DEFAULT 0 COMMENT '毛重（千克）',
    `jz`  	SMALLINT(10)        DEFAULT 0 COMMENT '净重（千克）',
    `hgckhwbgdsbrq`  		VARCHAR(16)        DEFAULT '' COMMENT '海关出口货物报关单申报日期',
    `sbdwmc`  		VARCHAR(64)        DEFAULT '' COMMENT '申报单位名称',
    `jzxh`  		VARCHAR(256)        DEFAULT '' COMMENT '集装箱号',
    `sbjldw_dm`  		VARCHAR(64)        DEFAULT '' COMMENT '申报计量单位代码',
    `sbjldwmc`  		VARCHAR(64)        DEFAULT '' COMMENT '申报计量单位名称',
    `sbdj`  		DECIMAL(17,2)        DEFAULT 0 COMMENT '申报单价',
    `sbsl1`  		SMALLINT(10)        DEFAULT 0 COMMENT '申报数量',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    INDEX idx_sale_order_no(`sale_order_no`),
    INDEX idx_hgcksp_dm(`hgcksp_dm`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='报关单商品';



DROP TABLE IF EXISTS `t_file_storage`;
CREATE TABLE `t_file_storage`  (
   `id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
   `biz_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '业务类型',
   `biz_no` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '业务编号',
   `file_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '文件类型',
   `name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '文件名称',
   `file_suffix` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '文件后缀',
   `original_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '原名称',
   `path` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '路径',
   `absolute_path` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '绝对路径/oss地址',
   `e_tag` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'oss eTag',
   `size` int(10) NULL DEFAULT NULL COMMENT '大小',
   `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
   `create_by` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '创建人',
   `update_by` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '修改人',
   `gmt_create` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
   `gmt_modified` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '修改时间',
   PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '文件存储信息表' ROW_FORMAT = Compact;



-- e签宝签署流程信息表
DROP TABLE IF EXISTS `e_sign_flow`;
CREATE TABLE `e_sign_flow`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `biz_sys_id`         VARCHAR(10)  DEFAULT '' COMMENT '业务系统id',
    `flow_id`            VARCHAR(64)        DEFAULT '' COMMENT '签署流程ID',
    `scene`            VARCHAR(64)        DEFAULT '' COMMENT '签署主题',
    `biz_type`         VARCHAR(32)        DEFAULT '' COMMENT '业务类型,目前单体架构下的冗余字段,用于区分业务回调',
    `status`            TINYINT(3)        DEFAULT 0 COMMENT '签署状态',
    `auto_archive`            TINYINT(3)      DEFAULT 1 COMMENT '是否自动归档',
    `expired_time`            datetime        DEFAULT NULL COMMENT '签署超时时间',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    INDEX idx_flow_id (`flow_id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='e签宝签署流程信息表';


-- e签宝签署文件表
DROP TABLE IF EXISTS `e_sign_file`;
CREATE TABLE `e_sign_file`
(
    `id`                 BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `flow_id`            VARCHAR(64)        DEFAULT '' COMMENT 'e签宝签署流程ID',
    `e_file_id`     VARCHAR(64)        DEFAULT '' COMMENT 'e签宝合同签署文件ID',
    `file_name`  VARCHAR(64)        DEFAULT '' COMMENT '文件名称（冗余字段，用于存证区分关键字）',
    `file_type`  VARCHAR(32)        DEFAULT '' COMMENT '文件类型（业务侧）',
    `raw_file_id`  BIGINT(20)        DEFAULT NULL COMMENT '未签署文件ID(文件系统)',
    `signed_file_id`  BIGINT(20)        DEFAULT NULL COMMENT '已签署文件ID(文件系统)',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='e签宝签署文件表';




-- e签宝流程签署方记录表
DROP TABLE IF EXISTS `e_sign_flow_signer`;
CREATE TABLE `e_sign_flow_signer`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `flow_id`            VARCHAR(64)      DEFAULT '' COMMENT '流程表ID',
    `e_account_id`       VARCHAR(64)      DEFAULT '' COMMENT '签署方账户ID',
    `status`            TINYINT(3)        DEFAULT 0 COMMENT '签署状态',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='e签宝流程签署方记录表';



-- e签宝签署人账户信息表
DROP TABLE IF EXISTS `e_sign_account`;
CREATE TABLE `e_sign_account`
(
    `id`                      BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `id_type`          VARCHAR(32)        DEFAULT '' COMMENT '签署人证件类型',
    `id_no`        VARCHAR(32)        DEFAULT '' COMMENT '签署人证件号码',
    `name`             VARCHAR(64)       DEFAULT '' COMMENT '签署人姓名',
    `phone`           VARCHAR(32)       DEFAULT '' COMMENT '签署人手机号',
    `email`            VARCHAR(64)       DEFAULT '' COMMENT '签署人邮箱',
    `e_account_id`  VARCHAR(64)        DEFAULT '' COMMENT '签署人e签宝账号ID',
    `deleted` TINYINT(1) DEFAULT 0 COMMENT '删除标识',
    `gmt_create`              TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
)ENGINE=InnoDB DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT='e签宝签署人账户信息表';


-- ----------------------------
-- Table structure for sys_country
-- ----------------------------
-- DROP TABLE IF EXISTS `sys_country`;
CREATE TABLE `sys_country`  (
    `id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `code` varchar(8) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NULL DEFAULT NULL COMMENT '国家/地区编码',
    `name` varchar(128) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NULL DEFAULT NULL COMMENT '名称',
    `continent` varchar(8) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NULL DEFAULT NULL COMMENT '大洲',
    `gradation` int(10) NULL DEFAULT NULL COMMENT '显示顺序',
    `level` tinyint(3) NULL DEFAULT 0 COMMENT '业务等级',
    `deleted` tinyint(1) NULL DEFAULT 0 COMMENT '删除标识',
    `gmt_create` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `gmt_modified` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '修改时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 130 CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '国家地区表' ROW_FORMAT = Dynamic;



-- data init sql
-- 文件模板
INSERT INTO `s_file_template`(`id`, `template_code`, `file_type`, `default_name`, `src_path`, `dest_dir`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (1, 'proformaInvoice', 'proformaInvoice', '形式发票', '/data/contract_template/xsfp.docx', 'trade-proforma_invoice', 0, '2024-09-18 14:03:15', '2024-10-15 15:52:20');
INSERT INTO `s_file_template`(`id`, `template_code`, `file_type`, `default_name`, `src_path`, `dest_dir`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (2, 'authorizationFile', 'authorizationFile', '授权委托书', '/data/contract_template/授权委托书-跨境通.docx', 'trade-user_document', 0, '2024-09-26 11:40:20', '2024-09-26 14:13:18');
INSERT INTO `s_file_template`(`id`, `template_code`, `file_type`, `default_name`, `src_path`, `dest_dir`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (3, 'salesContract', 'salesContract', '销售合同', '/data/contract_template/xsht.docx', 'trade-user_document', 0, '2024-09-28 10:14:50', '2024-09-28 10:15:21');
INSERT INTO `s_file_template`(`id`, `template_code`, `file_type`, `default_name`, `src_path`, `dest_dir`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (4, 'platformCommitmentLetter', 'platformCommitmentLetter', '承诺函', '/data/contract_template/承诺函-贸易公司.docx', 'trade-purchase_contract', 0, '2024-09-28 14:56:31', '2024-09-28 15:03:04');
INSERT INTO `s_file_template`(`id`, `template_code`, `file_type`, `default_name`, `src_path`, `dest_dir`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (5, 'purchaseContractFile', 'purchaseContractFile', '采购合同', '/data/contract_template/采购合同-跨境通.docx', 'trade-purchase_contract', 0, '2024-09-28 14:56:35', '2024-09-28 15:02:57');
INSERT INTO `s_file_template`(`id`, `template_code`, `file_type`, `default_name`, `src_path`, `dest_dir`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (6, 'purchaseOrderInvoiceNotice', 'purchaseOrderInvoiceNotice', '采购订单开票通知书', '/data/contract_template/pokptz.docx', 'trade-user_document', 0, '2024-10-09 20:38:35', '2024-10-09 20:39:11');



-- 城市信息表
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (1, 'AD', '安道尔共和国', 'Europe', 0, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (2, 'AE', '阿拉伯联合酋长国', 'Asia', 1, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (3, 'CN', '中国', 'Asia', 2, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (4, 'HK', '中国香港', 'Asia', 3, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (5, 'SG', '新加坡', 'Asia', 4, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (6, 'DE', '德国', 'Europe', 5, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (7, 'IT', '意大利', 'Europe', 6, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (8, 'FR', '法国', 'Europe', 7, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (9, 'GB', '英国', 'Europe', 8, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (10, 'NL', '荷兰', 'Europe', 9, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (11, 'PT', '葡萄牙', 'Europe', 10, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (12, 'ES', '西班牙', 'Europe', 11, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (13, 'DK', '丹麦', 'Europe', 12, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (14, 'BG', '保加利亚', 'Europe', 13, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (15, 'HR', '克罗地亚', 'Europe', 14, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (16, 'IS', '冰岛', 'Europe', 15, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (17, 'HU', '匈牙利', 'Europe', 16, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (18, 'LU', '卢森堡', 'Europe', 17, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (19, 'CY', '塞浦路斯', 'Europe', 18, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (20, 'GR', '希腊', 'Europe', 19, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (21, 'LV', '拉脱维亚', 'Europe', 20, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (22, 'NO', '挪威', 'Europe', 21, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (23, 'CZ', '捷克', 'Europe', 22, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (24, 'SK', '斯洛伐克', 'Europe', 23, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (25, 'SI', '斯洛文尼亚', 'Europe', 24, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (26, 'BE', '比利时', 'Europe', 25, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (27, 'PL', '波兰', 'Europe', 26, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (28, 'AU', '澳大利亚', 'Oceania', 27, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (29, 'IE', '爱尔兰', 'Europe', 28, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (30, 'EE', '爱沙尼亚', 'Europe', 29, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (31, 'SE', '瑞典', 'Europe', 30, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (32, 'GI', '直布罗陀', 'Europe', 31, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (33, 'LT', '立陶宛', 'Europe', 32, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (34, 'RO', '罗马尼亚', 'Europe', 33, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (35, 'FI', '芬兰', 'Europe', 34, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (36, 'MT', '马耳他', 'Europe', 35, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (37, 'KR', '韩国', 'Asia', 36, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (38, 'US', '美国', 'NAmerica', 37, 1, 0, '2024-06-12 06:53:23', '2024-06-13 11:45:14');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (39, 'AG', '安提瓜和巴布达', 'NAmerica', 38, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (40, 'AI', '安圭拉岛', 'NAmerica', 39, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (41, 'AL', '阿尔巴尼亚', 'Europe', 40, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (42, 'AM', '亚美尼亚', 'Asia', 41, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (43, 'AN', '库拉索岛', 'NAmerica', 42, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (44, 'AO', '安哥拉', 'Africa', 43, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (45, 'AR', '阿根廷', 'SAmerica', 44, 2, 0, '2024-06-12 06:53:23', '2024-06-13 11:44:27');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (46, 'AT', '奥地利', 'Europe', 45, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (47, 'AW', '阿鲁巴', 'NAmerica', 46, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (48, 'AZ', '阿塞拜疆', 'Asia', 47, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (49, 'BA', '波斯尼亚和黑塞哥维那', 'Europe', 48, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (51, 'BH', '巴林', 'Asia', 50, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (52, 'BO', '玻利维亚', 'SAmerica', 51, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (53, 'BR', '巴西', 'SAmerica', 52, 1, 0, '2024-06-12 06:53:23', '2024-06-13 11:44:24');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (54, 'CA', '加拿大', 'NAmerica', 53, 1, 0, '2024-06-12 06:53:23', '2024-06-13 11:45:14');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (55, 'CH', '瑞士', 'Europe', 54, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (56, 'CL', '智利', 'SAmerica', 55, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (57, 'CO', '哥伦比亚', 'SAmerica', 56, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (58, 'CR', '哥斯达黎加', 'NAmerica', 57, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (59, 'DM', '多米尼克', 'NAmerica', 58, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (60, 'DO', '多米尼加', 'NAmerica', 59, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (61, 'DZ', '阿尔及利亚', 'Africa', 60, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (62, 'EC', '厄瓜多尔', 'SAmerica', 61, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (63, 'EG', '埃及', 'Asia', 62, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (65, 'GD', '格林纳达', 'NAmerica', 64, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (66, 'GE', '格鲁吉亚', 'Asia', 65, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (67, 'GG', '根西', 'Europe', 66, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (68, 'GQ', '赤道几内亚', 'Africa', 67, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (69, 'GT', '危地马拉', 'NAmerica', 68, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (70, 'GY', '圭亚那', 'SAmerica', 69, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (71, 'HN', '洪都拉斯', 'NAmerica', 70, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (73, 'IL', '以色列', 'Asia', 72, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (74, 'IM', '马恩岛', 'Europe', 73, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (75, 'IN', '印度', 'Asia', 74, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (76, 'JE', '泽西岛', 'Europe', 75, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (77, 'JM', '牙买加', 'NAmerica', 76, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (78, 'JO', '约旦', 'Asia', 77, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (79, 'JP', '日本', 'Asia', 78, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (80, 'KE', '肯尼亚', 'Africa', 79, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (81, 'KG', '吉尔吉斯斯坦', 'Asia', 80, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (82, 'KH', '柬埔寨', 'Asia', 81, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (83, 'KZ', '哈萨克斯坦', 'Asia', 82, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (84, 'KW', '科威特', 'Asia', 83, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (85, 'LB', '黎巴嫩', 'Asia', 84, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (86, 'LI', '列支敦士登', 'Europe', 85, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (87, 'LK', '斯里兰卡', 'Asia', 86, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (88, 'MA', '摩洛哥', 'Africa', 87, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (89, 'MC', '摩纳哥', 'Europe', 88, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (90, 'MD', '摩尔多瓦', 'Europe', 89, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (91, 'MK', '马其顿', 'Europe', 90, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (92, 'MO', '澳门', 'Asia', 91, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (93, 'MQ', '马提尼克', 'NAmerica', 92, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (94, 'MU', '毛里求斯', 'Africa', 93, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (95, 'MV', '马尔代夫', 'Asia', 94, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (96, 'MX', '墨西哥', 'NAmerica', 95, 1, 0, '2024-06-12 06:53:23', '2024-06-13 11:45:14');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (97, 'MY', '马来西亚', 'Asia', 96, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (98, 'NG', '尼日利亚', 'Africa', 97, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (99, 'NI', '尼加拉瓜', 'NAmerica', 98, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (100, 'NP', '尼泊尔', 'Asia', 99, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (101, 'NZ', '新西兰', 'Oceania', 100, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (102, 'OM', '阿曼', 'Asia', 101, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (103, 'PA', '巴拿马', 'NAmerica', 102, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (104, 'PE', '秘鲁', 'SAmerica', 103, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (105, 'PF', '法属波利尼西亚', 'Asia', 104, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (106, 'PH', '菲律宾', 'Asia', 105, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (107, 'PK', '巴基斯坦', 'Asia', 106, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (108, 'PM', '圣皮埃尔和密克隆', 'NAmerica', 107, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (109, 'PR', '波多黎各', 'NAmerica', 108, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (110, 'PY', '巴拉圭', 'SAmerica', 109, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (111, 'QA', '卡塔尔', 'Asia', 110, 3, 0, '2024-06-12 06:53:23', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (112, 'RS', '塞尔维亚', 'Europe', 111, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (113, 'SA', '沙特阿拉伯', 'Asia', 112, 1, 0, '2024-06-12 06:53:23', '2024-06-13 03:54:42');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (114, 'SC', '塞舌尔', 'Africa', 113, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (115, 'SM', '圣马力诺', 'Europe', 114, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (116, 'SV', '萨尔瓦多', 'NAmerica', 115, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (117, 'TH', '泰国', 'Asia', 116, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (118, 'TJ', '塔吉克斯坦', 'Asia', 117, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (119, 'TN', '突尼斯', 'Africa', 118, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (120, 'TR', '土耳其', 'Europe', 119, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (121, 'TW', '中国台湾', 'Asia', 120, 2, 0, '2024-06-12 06:53:23', '2024-06-13 05:46:40');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (122, 'UG', '乌干达', 'Africa', 121, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (123, 'UY', '乌拉圭', 'SAmerica', 122, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (124, 'UZ', '乌兹别克斯坦', 'Asia', 123, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (125, 'VN', '越南', 'Asia', 124, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (126, 'VU', '瓦努阿图', 'Oceania', 125, 5, 0, '2024-06-12 06:53:23', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (127, 'YT', '马约特', 'Africa', 126, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (129, 'ZM', '赞比亚', 'Africa', 128, 4, 0, '2024-06-12 06:53:23', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (130, 'RU', '俄罗斯', 'Europe', 129, 5, 0, '2024-06-13 03:46:10', '2024-06-13 07:17:20');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (131, 'ET', '埃塞俄比亚', 'Africa', 132, 3, 0, '2024-06-13 10:52:59', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (132, 'BJ', '贝宁', 'Africa', 134, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (133, 'BW', '博茨瓦纳', 'Africa', 135, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (134, 'BF', '布基纳法索', 'Africa', 136, 5, 0, '2024-06-13 10:52:59', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (135, 'BI', '布隆迪', 'Africa', 137, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (136, 'TG', '多哥', 'Africa', 139, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (137, 'ER', '厄立特里亚', 'Africa', 140, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (138, 'CV', '佛得角', 'Africa', 141, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (139, 'GM', '冈比亚', 'Africa', 142, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (140, 'CG', '刚果（布）', 'Africa', 143, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (141, 'CD', '刚果（金）', 'Africa', 144, 5, 0, '2024-06-13 10:52:59', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (142, 'DJ', '吉布提', 'Africa', 145, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (143, 'GN', '几内亚', 'Africa', 146, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (144, 'GW', '几内亚比绍', 'Africa', 147, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (145, 'GH', '加纳', 'Africa', 148, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (146, 'GA', '加蓬', 'Africa', 149, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (147, 'ZW', '津巴布韦', 'Africa', 150, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (148, 'CM', '喀麦隆', 'Africa', 151, 5, 0, '2024-06-13 10:52:59', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (149, 'KM', '科摩罗', 'Africa', 152, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (150, 'CI', '科特迪瓦', 'Africa', 153, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (151, 'LS', '莱索托', 'Africa', 155, 4, 0, '2024-06-13 10:52:59', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (152, 'LR', '利比里亚', 'Africa', 156, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (153, 'LY', '利比亚', 'Africa', 157, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (154, 'RW', '卢旺达', 'Africa', 158, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (155, 'MG', '马达加斯加', 'Africa', 159, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (156, 'MW', '马拉维', 'Africa', 160, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (157, 'ML', '马里', 'Africa', 161, 5, 0, '2024-06-13 10:53:00', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (158, 'MR', '毛里塔尼亚', 'Africa', 163, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (159, 'MZ', '莫桑比克', 'Africa', 165, 5, 0, '2024-06-13 10:53:00', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (160, 'NA', '纳米比亚', 'Africa', 166, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (161, 'ZA', '南非', 'Africa', 167, 5, 0, '2024-06-13 10:53:00', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (162, 'SS', '南苏丹', 'Africa', 168, 5, 0, '2024-06-13 10:53:00', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (163, 'NE', '尼日尔', 'Africa', 169, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (164, 'SL', '塞拉利昂', 'Africa', 171, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (165, 'SN', '塞内加尔', 'Africa', 172, 5, 0, '2024-06-13 10:53:00', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (166, 'ST', '圣多美和普林西比', 'Africa', 174, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (167, 'SZ', '斯威士兰', 'Africa', 175, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (168, 'SD', '苏丹', 'Africa', 176, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (169, 'SO', '索马里', 'Africa', 177, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (170, 'TZ', '坦桑尼亚', 'Africa', 178, 5, 0, '2024-06-13 10:53:00', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (171, 'TD', '乍得和中非', 'Africa', 182, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (172, 'MN', '蒙古', 'Asia', 184, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (173, 'KP', '朝鲜', 'Asia', 185, 5, 0, '2024-06-13 10:53:00', '2024-06-13 11:55:10');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (174, 'LA', '老挝', 'Asia', 189, 4, 0, '2024-06-13 10:53:00', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (175, 'MM', '缅甸', 'Asia', 192, 5, 0, '2024-06-13 10:53:01', '2024-06-13 11:55:10');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (176, 'ID', '印度尼西亚', 'Asia', 195, 1, 0, '2024-06-13 10:53:01', '2024-06-13 12:34:12');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (177, 'BN', '文莱', 'Asia', 196, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (178, 'TL', '帝汶', 'Asia', 198, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (179, 'BD', '孟加拉国', 'Asia', 201, 3, 0, '2024-06-13 10:53:01', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (180, 'BT', '不丹', 'Asia', 203, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (181, 'TM', '土库曼斯坦', 'Asia', 210, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (182, 'AF', '阿富汗', 'Asia', 211, 5, 0, '2024-06-13 10:53:01', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (183, 'IQ', '伊拉克', 'Asia', 212, 3, 0, '2024-06-13 10:53:01', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (184, 'IR', '伊朗', 'Asia', 213, 5, 0, '2024-06-13 10:53:01', '2024-06-13 11:55:10');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (185, 'SY', '叙利亚', 'Asia', 214, 5, 0, '2024-06-13 10:53:01', '2024-06-13 11:55:10');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (186, 'PS', '巴勒斯坦', 'Asia', 218, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (187, 'YE', '也门', 'Asia', 221, 5, 0, '2024-06-13 10:53:01', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (188, 'BY', '白俄罗斯', 'Europe', 252, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (189, 'UA', '乌克兰', 'Europe', 254, 3, 0, '2024-06-13 10:53:01', '2024-06-13 11:47:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (190, 'ME', '黑山', 'Europe', 259, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (193, 'VA', '梵蒂冈', 'Europe', 268, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (195, 'BZ', '伯利兹', 'NAmerica', 283, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (196, 'BS', '巴哈马', 'NAmerica', 287, 4, 0, '2024-06-13 10:53:01', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (197, 'CU', '古巴', 'NAmerica', 288, 5, 0, '2024-06-13 10:53:01', '2024-06-13 11:55:10');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (198, 'HT', '海地', 'NAmerica', 290, 5, 0, '2024-06-13 10:53:01', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (199, 'KN', '圣基茨和尼维斯', 'NAmerica', 293, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (201, 'LC', '圣卢西亚', 'NAmerica', 296, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (202, 'VC', '圣文森特和格林纳丁斯', 'NAmerica', 297, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (203, 'BB', '巴巴多斯', 'NAmerica', 298, 5, 0, '2024-06-13 10:53:02', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (204, 'TT', '特立尼达和多巴哥', 'NAmerica', 300, 5, 0, '2024-06-13 10:53:02', '2024-06-13 12:13:04');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (209, 'SR', '苏里南', 'SAmerica', 314, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (210, 'VE', '委内瑞拉', 'SAmerica', 315, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (211, 'PG', '巴布亚新几内亚', 'Oceania', 320, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (212, 'SB', '所罗门群岛', 'Oceania', 321, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (213, 'FJ', '斐济', 'Oceania', 323, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (214, 'WS', '萨摩亚', 'Oceania', 324, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (215, 'TO', '汤加', 'Oceania', 325, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (216, 'CK', '库克群岛', 'Oceania', 326, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (217, 'NU', '纽埃', 'Oceania', 327, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (218, 'FM', '密克罗尼西亚联邦', 'Oceania', 328, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (219, 'PW', '帕劳', 'Oceania', 329, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (220, 'MH', '马绍尔群岛', 'Oceania', 330, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (221, 'NR', '瑙鲁', 'Oceania', 331, 4, 0, '2024-06-13 10:53:02', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (222, 'TV', '图瓦卢', 'Oceania', 332, 4, 0, '2024-06-13 10:53:03', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (223, 'KI', '基里巴斯', 'Oceania', 333, 4, 0, '2024-06-13 10:53:03', '2024-06-13 12:16:41');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (225, 'KMD', '开曼群岛', 'Europe', 334, 5, 0, '2024-06-13 12:17:57', '2024-06-13 12:19:29');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (226, 'KLM', '克里米亚', 'Europe', 335, 5, 0, '2024-06-13 12:21:38', '2024-06-13 12:21:59');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (227, 'DNT', '顿涅茨克', 'Europe', 336, 5, 0, '2024-06-13 12:22:58', '2024-06-13 12:23:36');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (228, 'LHK', '卢甘斯克', 'Europe', 337, 5, 0, '2024-06-13 12:23:59', '2024-06-13 12:25:53');
INSERT INTO `sys_country`(`id`, `code`, `name`, `continent`, `gradation`, `level`, `deleted`, `gmt_create`, `gmt_modified`) VALUES (229, 'BSD', '北苏丹', 'Africa', 338, 5, 0, '2024-06-13 12:25:42', '2024-06-13 12:27:31');
