/**
 * @filename:!BillingDisbursement 2024-10-28
 * @project KJT v1.1.0 Copyright(c) 2024 wanglang Co. Ltd. All right reserved.
 */
package com.trade.service.finance.disbursement.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.trade.common.core.domain.BizBaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotEmpty;
import java.math.BigDecimal;
import java.time.LocalDate;

/**
 * @Description:出账表实体类
 * @version: v1.1.0
 * @author: wanglang
 */
@Data
@EqualsAndHashCode(callSuper = false)
// @Accessors(chain = true)
@ApiModel(value = "出账基础信息", description = "出账基础信息")
public class BillingDisbursement extends BizBaseEntity {

    private static final long serialVersionUID = 1730115260020L;
    @ApiModelProperty(name = "customerUserId", value = "客户id")
    private Long customerUserId;
    @ApiModelProperty(name = "paymentBasicId", value = "支付基础表id")
    private Long paymentBasicId;
    @ApiModelProperty(name = "separateAccountsInfoId", value = "分账信息主表id")
    private Long separateAccountsInfoId;
    @ApiModelProperty(name = "businessNumber", value = "业务编号")
    private String businessNumber;
    @ApiModelProperty(name = "salesContractNo", value = "合同编号")
    private String salesContractNo;
    @ApiModelProperty(name = "contractName", value = "合同名称")
    private String contractName;
    @ApiModelProperty(name = "importerCertNo", value = "进口商统一社会信用代码/注册号")
    private String importerCertNo;
    @ApiModelProperty(name = "importerEnterpriseName", value = "进口商企业名称")
    private String importerEnterpriseName;
    @ApiModelProperty(name = "agencyCertNo", value = "代理公司统一社会信用代码/注册号")
    private String agencyCertNo;
    @ApiModelProperty(name = "agencyEnterpriseName", value = "代理公司企业名称")
    private String agencyEnterpriseName;
    @ApiModelProperty(name = "financierIdentifier", value = "资金方标识")
    private String financierIdentifier;
    @ApiModelProperty(name = "paymentType", value = "款项类型分账类型1出口退税款2贸易回款3预收货款4贸易融资款5贷款差额6贷款结汇差额")
    private String paymentType;
    @ApiModelProperty(name = "status", value = "入账状态1待确认2已完成")
    private String status;
    @ApiModelProperty(name = "transactionNumber", value = "交易编号")
    private String transactionNumber;
    @ApiModelProperty(name = "paymentAmount", value = "付款金额")
    private BigDecimal paymentAmount;
    @ApiModelProperty(name = "paymentCurrency", value = "付款金额币种代码")
    private String paymentCurrency;
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @ApiModelProperty(name = "paymentDate", value = "付款日期")
    private LocalDate paymentDate;
    @ApiModelProperty(name = "entryBusinessNumber", value = "入账业务编号")
    private String entryBusinessNumber;
    @ApiModelProperty(name = "tradeParticipantsIdentifier", value = "贸易参与方标识/收款方名称")
    private String tradeParticipantsIdentifier;
    @ApiModelProperty(name = "payeeType", value = "收款方类型1客户2资金方")
    private String payeeType;
    @ApiModelProperty(name = "payerType", value = "付款方类型1代理公司2资金方3税务局")
    private String payerType;
    @ApiModelProperty(name = "payerName", value = "付款方名称")
    private String payerName;
    @ApiModelProperty(name = "source", value = "来源1B端2C端")
    private Integer source;
    @ApiModelProperty(name = "voucherNo", value = "凭证号")
    private String voucherNo;
    @ApiModelProperty(name = "accountNumber", value = "付款银行账号")
    private String accountNumber;
}
